# -*- Mode: rpm-spec -*-
#
# This Specfile is based on kernel-tmb spec done by
# Thomas Backlund <tmb@mandriva.org>
# 
# The mkflavour() macroization done by Anssi Hannula <anssi@mandriva.org>
#
# Note! remember to push kernel-userspace-headers and
# the preouilt kernel drivers (kmod-<driver>)
#
# Mageia kernels use kernel.org versioning
#
%define kernelversion	3
%define patchlevel	14
# sublevel is now used for -stable patches
%define sublevel	41
# extstable is for extended stable patches
%define extstable	0

# Package release
%define mgarel		1

# kernel Makefile extraversion is substituted by
# kpatch wich are either 0 (empty), rc (kpatch)
%define kpatch		0
# kernel.org -gitX patch (only the number after "git")
%define kgit		0

# kernel base name (also name of srpm)
%define kname 		kernel

# Patch tarball tag
%define ktag		mga

%define rpmtag		%{distsuffix}%{mgaver}
%if %kpatch
%if %kgit
%define rpmrel		%mkrel 0.%{kpatch}.%{kgit}.%{mgarel}
%else
%define rpmrel		%mkrel 0.%{kpatch}.%{mgarel}
%endif
%else
%define rpmrel		%mkrel %{mgarel}
%endif

# fakerel and fakever never change, they are used to fool
# rpm/urpmi/smart
%define fakever		1
%define fakerel 	%mkrel 1

# version defines
%if %extstable
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}.%{extstable}
%else
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}
%endif
%define kverrel   	%{kversion}-%{rpmrel}

# When we are using a pre/rc patch, the tarball is a sublevel -1
%if %kpatch
%if %sublevel
%define tar_ver   	%{kernelversion}.%{patchlevel}
%else
%define tar_ver		%{kernelversion}.%(expr %{patchlevel} - 1)
%endif
%define patch_ver 	%{kversion}-%{kpatch}-%{ktag}%{mgarel}
%else
%define tar_ver   	%{kernelversion}.%{patchlevel}
%define patch_ver 	%{kversion}-%{ktag}%{mgarel}
%endif

# Used for not making too long names for rpms or search paths
%if %kpatch
%if %kgit
%define buildrpmrel     0.%{kpatch}.%{kgit}.%{mgarel}%{rpmtag}
%else
%define buildrpmrel     0.%{kpatch}.%{mgarel}%{rpmtag}
%endif
%else
%define buildrpmrel     %{mgarel}%{rpmtag}
%endif
%define buildrel     	%{kversion}-%{buildrpmrel}

# Having different top level names for packges means that you have to remove
# them by hard :(
%define top_dir_name 	%{kname}-%{_arch}

%define build_dir 	${RPM_BUILD_DIR}/%{top_dir_name}
%define src_dir 	%{build_dir}/linux-%{tar_ver}

# Disable useless debug rpms...
%define _enable_debug_packages 	%{nil}
%define debug_package 		%{nil}

# Build defines
%define build_doc 		1
%define build_source 		1
%define build_devel 		1

%define build_debug 		1

# Build desktop i586 / 4GB
%ifarch %{ix86}
%define build_desktop586	1
%endif

# Build desktop (i686 / 4GB) / x86_64
%define build_desktop		1

# Build server (i686 / 64GB)/x86_64 / sparc64 sets
%define build_server		1

# build perf and cpupower tools
%define build_perf		1
%define build_cpupower		1

# compress modules with xz
%define build_modxz		1

# ARM builds
%ifarch %{arm}
%define build_desktop		0
%define build_server		0
%define build_iop32x		0
%define build_kirkwood		1
%define build_versatile		1
# no cpupower tools on arm yet
%define build_cpupower		0
# arm is currently not using xz
%define build_modxz		0
%endif
# End of user definitions

# buildtime flags
%{?_without_desktop586: %global build_desktop586 0}
%{?_without_desktop: %global build_desktop 0}
%{?_without_server: %global build_server 0}
%{?_without_doc: %global build_doc 0}
%{?_without_source: %global build_source 0}
%{?_without_devel: %global build_devel 0}
%{?_without_debug: %global build_debug 0}
%{?_without_perf: %global build_perf 0}
%{?_without_cpupower: %global build_cpupower 0}
%{?_without_modxz: %global build_modxz 0}

%{?_with_desktop586: %global build_desktop586 1}
%{?_with_desktop: %global build_desktop 1}
%{?_with_server: %global build_server 1}
%{?_with_doc: %global build_doc 1}
%{?_with_source: %global build_source 1}
%{?_with_devel: %global build_devel 1}
%{?_with_debug: %global build_debug 1}
%{?_with_perf: %global build_perf 1}
%{?_with_cpupower: %global build_cpupower 1}
%{?_with_modxz: %global build_modxz 1}

# ARM builds
%{?_with_iop32x: %global build_iop32x 1}
%{?_with_kirkwood: %global build_kirkwood 1}
%{?_with_versatile: %global build_versatile 1}
%{?_without_iop32x: %global build_iop32x 0}
%{?_without_kirkwood: %global build_kirkwood 0}
%{?_without_versatile: %global build_versatile 0}

# For the .nosrc.rpm
%define build_nosrc 	0
%{?_with_nosrc: %global build_nosrc 1}

%if %(if [ -z "$CC" ] ; then echo 0; else echo 1; fi)
%define kmake %make CC="$CC"
%else
%define kmake %make
%endif
# there are places where parallel make don't work
%define smake make

# Parallelize xargs invocations on smp machines
%define kxargs xargs %([ -z "$RPM_BUILD_NCPUS" ] \\\
	&& RPM_BUILD_NCPUS="`/usr/bin/getconf _NPROCESSORS_ONLN`"; \\\
	[ "$RPM_BUILD_NCPUS" -gt 1 ] && echo "-P $RPM_BUILD_NCPUS")

# Sparc arch wants sparc64 kernels
%define target_arch    %(echo %{_arch} | sed -e 's/mips.*/mips/' -e 's/arm.*/arm/')


#
# SRC RPM description
#
Summary: 	Linux kernel built for Mageia
Name:		%{kname}
Version: 	%{kversion}
Release: 	%{rpmrel}
License: 	GPLv2
Group: 	 	System/Kernel and hardware
ExclusiveArch: %{ix86} x86_64 %{arm}
ExclusiveOS: 	Linux
URL:            http://www.kernel.org

####################################################################
#
# Sources
#
### This is for full SRC RPM
Source0: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/linux-%{tar_ver}.tar.xz
Source1: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/linux-%{tar_ver}.tar.sign
### This is for stripped SRC RPM
%if %build_nosrc
NoSource: 0
%endif
# This is for disabling *config, mrproper, prepare, scripts on -devel rpms
Source2: 	disable-mrproper-prepare-scripts-configs-in-devel-rpms.patch

Source4: 	README.kernel-sources

# config and systemd service file from fedora
Source50:	cpupower.service
Source51:	cpupower.config

# our patch tarball
Source100: 	linux-%{patch_ver}.tar.xz

####################################################################
#
# Patches

#
# Patch0 to Patch100 are for core kernel upgrades.
#

# Pre linus patch: ftp://ftp.kernel.org/pub/linux/kernel/v3.0/testing

%if %kpatch
%if %sublevel
Patch2:		ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/stable-review/patch-%{kversion}-%{kpatch}.xz
Source11:	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/stable-review/patch-%{kversion}-%{kpatch}.sign
%else
Patch1:		ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/testing/patch-%{kernelversion}.%{patchlevel}-%{kpatch}.xz
Source10: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/testing/patch-%{kernelversion}.%{patchlevel}-%{kpatch}.sign
%endif
%endif
%if %kgit
Patch2:		ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/snapshots/patch-%{kernelversion}.%{patchlevel}-%{kpatch}-git%{kgit}.xz
Source11: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/snapshots/patch-%{kernelversion}.%{patchlevel}-%{kpatch}-git%{kgit}.sign
%endif
%if %sublevel
%if %kpatch
%define prev_sublevel %(expr %{sublevel} - 1)
%if %prev_sublevel
Patch1:   	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kernelversion}.%{patchlevel}.%{prev_sublevel}.xz
Source10: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kernelversion}.%{patchlevel}.%{prev_sublevel}.sign
%endif
%else
Patch1:   	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kernelversion}.%{patchlevel}.%{sublevel}.xz
Source10: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kernelversion}.%{patchlevel}.%{sublevel}.sign
%endif
%endif
%if %extstable
Patch3:		patch-%{kernelversion}.%{patchlevel}.%{sublevel}.%{extstable}.patch
%endif

#END
####################################################################

# Defines for the things that are needed for all the kernels
#
%define common_desc_kernel The kernel package contains the Linux kernel (vmlinuz), the core of your \
Mageia operating system. The kernel handles the basic functions \
of the operating system: memory allocation, process allocation, device \
input and output, etc.

%define common_desc_kernel_smp This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.

### Global Requires/Provides
%define requires1	bootloader-utils >= 1.16-1
%define requires2	dracut >= 034-12.3
%define requires3	kmod >= 15-2.3
%define requires4	sysfsutils >= 2.1.0-16
%define requires5	kernel-firmware >= 20130624-1

%define kprovides1 	%{kname} = %{kverrel}
%define kprovides2 	kernel = %{tar_ver}
%define kprovides3 	alsa = 1.0.26
%define kprovides_server drbd-api = 88

%define	kobsoletes1	dkms-r8192se <= 0019.1207.2010-2
%define	kobsoletes2	dkms-lzma <= 4.43-32
%define	kobsoletes3	dkms-psb <= 4.41.1-7
# conflict dkms packages that dont support kernel-3.14
%define kconflicts1	dkms-broadcom-wl < 6.30.223.141-1
%define kconflicts2	dkms-fglrx < 14.010.1006-1
%define kconflicts3	dkms-nvidia-current < 331.79-1
%define kconflicts4	dkms-nvidia304 < 304.121-1
%define kconflicts5	dkms-nvidia173 < 173.14.39-2
# (tmb) nvidia96xx does not support this kernel or x11-server-1.13
%define kconflicts6	dkms-nvidia96xx <= 96.43.23
%define kconflicts7	dkms-xtables-addons < 2.5-1
# (tmb) conflict too old lvm2 rules to make upgrades work (tv, mga #9536)
%define kconflicts8	lvm2 < 2.02.98-3
# (tmb) conflict too old drakxtools-backend to avoid bogus root=/dev/ (#9536)
%define kconflicts9	drakxtools-backend < 15.37-1
# (tmb) conflict older btrfs-progs to get the new in same transaction and in initrd
%define kconflicts10	btrfs-progs < 3.14.2-1
# (tmb) conflict too old plymouth (#10128)
%define kconflicts11	plymouth < 0.8.6.1-8
# (tmb) conflict too old radeon-firmware to get the uvd firmwares in initrd
%define kconflicts12	radeon-firmware < 20140828-1
# (tmb) conflict older nonfree firmware to get updated ones in initrd
%define kconflicts13	kernel-firmware-nonfree < 20140828-1

Autoreqprov: 		no

BuildRequires: 		gcc >= 4.8.2-3.1
BuildRequires: 		binutils >= 1:2.24-0.20131016.1
BuildRequires: 		kmod >= 15-2.3
BuildRequires: 		bc
# for unversioned kmod provides (mga#14235)
BuildRequires:		rpm-mageia-setup-build >= 1.197-1.1
# for cpupower
%if %{build_cpupower}
BuildRequires:		pciutils-devel
%endif
# for perf
%if %{build_perf}
BuildRequires:		audit-devel
BuildRequires:		binutils-devel
BuildRequires:		elfutils-devel
BuildRequires:		gtk2-devel
BuildRequires:		libunwind-devel
BuildRequires:		newt-devel
BuildRequires:		python-devel
BuildRequires:		zlib-devel
BuildRequires:		asciidoc
BuildRequires:		bison
BuildRequires:		flex
BuildRequires:		xmlto
%endif


%description
%common_desc_kernel
%ifnarch %{arm}
%common_desc_kernel_smp
%endif

# Define obsolete/provides to help automatic upgrades of old kernel-xen-pvops
%define latest_obsoletes_server kernel-xen-pvops-latest < 3.2.1-1
%define latest_provides_server kernel-xen-pvops-latest = %{kverrel}
%define latest_obsoletes_devel_server kernel-xen-pvops-devel-latest < 3.2.1-1
%define latest_provides_devel_server kernel-xen-pvops-devel-latest = %{kverrel}
# Define obsolete/provides to help automatic upgrades of old kernel-netbook
%define latest_obsoletes_desktop kernel-netbook-latest < 3.7.0-0.rc8.1
%define latest_provides_desktop kernel-netbook-latest = %{kverrel}
%define latest_obsoletes_devel_desktop kernel-netbook-devel-latest < 3.7.0-0.rc8.1
%define latest_provides_devel_desktop kernel-netbook-devel-latest = %{kverrel}

# mkflavour() name flavour processor
# name: the flavour name in the package name
# flavour: first parameter of CreateKernel()
%define mkflavour()					\
%package -n %{kname}-%{1}-%{buildrel}			\
Version:	%{fakever}				\
Release:	%{fakerel}				\
Provides:	%kprovides1 %kprovides2 %kprovides3	\
%{expand:%%{?kprovides_%{1}:Provides: %{kprovides_%{1}}}} \
Provides:	%{kname}-%{1}				\
Requires(pre):	%requires1 %requires2 %requires3 %requires4 \
Requires:	%requires2 %requires5			\
Obsoletes:	%kobsoletes1 %kobsoletes2 %kobsoletes3	\
Conflicts:	%kconflicts1 %kconflicts2 %kconflicts3	\
Conflicts:	%kconflicts4 %kconflicts5 %kconflicts6	\
Conflicts:	%kconflicts7 %kconflicts8 %kconflicts9	\
Conflicts:	%kconflicts10 %kconflicts11 %kconflicts12 \
Conflicts:	%kconflicts13				\
Provides:	should-restart = system			\
Suggests:	crda iw cpupower			\
Suggests:	%{kname}-%{1}-latest			\
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
Summary:	%{expand:%{summary_%(echo %{1} | sed -e "s/-/_/")}} \
Group:		System/Kernel and hardware		\
%description -n %{kname}-%{1}-%{buildrel}		\
%common_desc_kernel %{expand:%{info_%(echo %{1} | sed -e "s/-/_/")}} \
%ifnarch %{arm}						\
%common_desc_kernel_smp					\
%endif							\
							\
%if %build_devel					\
%package -n	%{kname}-%{1}-devel-%{buildrel}		\
Version:	%{fakever}				\
Release:	%{fakerel}				\
Requires:	glibc-devel ncurses-devel make gcc perl	\
Summary:	The kernel-devel files for %{kname}-%{1}-%{buildrel} \
Group:		Development/Kernel			\
Provides:	%{kname}-devel = %{kverrel} 		\
Provides:	%{kname}-%{1}-devel			\
Suggests:	%{kname}-%{1}-devel-latest		\
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
%description -n %{kname}-%{1}-devel-%{buildrel}		\
This package contains the kernel files (headers and build tools) \
that should be enough to build additional drivers for   \
use with %{kname}-%{1}-%{buildrel}.                     \
							\
If you want to build your own kernel, you need to install the full \
%{kname}-source-%{buildrel} rpm.			\
							\
%endif							\
							\
%if %build_debug					\
%package -n	%{kname}-%{1}-%{buildrel}-debuginfo	\
Version:	%{fakever}				\
Release:	%{fakerel}				\
Summary:	Files with debuginfo for %{kname}-%{1}-%{buildrel} \
Group:		Development/Debug			\
Provides:	kernel-debug = %{kverrel} 		\
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
%description -n %{kname}-%{1}-%{buildrel}-debuginfo	\
This package contains the files with debuginfo to aid in debug tasks \
when using %{kname}-%{1}-%{buildrel}.			\
							\
If you need to look at debug information or use some application that \
needs debugging info from the kernel, this package may help. \
							\
%endif							\
							\
%package -n %{kname}-%{1}-latest			\
Version:	%{kversion}				\
Release:	%{rpmrel}				\
Summary:	Virtual rpm for latest %{kname}-%{1}	\
Group:		System/Kernel and hardware		\
Requires:	%{kname}-%{1}-%{buildrel}		\
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
%{expand:%%{?latest_obsoletes_%{1}:Obsoletes: %{latest_obsoletes_%{1}}}} \
%{expand:%%{?latest_provides_%{1}:Provides: %{latest_provides_%{1}}}} \
%description -n %{kname}-%{1}-latest			\
This package is a virtual rpm that aims to make sure you always have the \
latest %{kname}-%{1} installed...			\
							\
%if %build_devel					\
%package -n %{kname}-%{1}-devel-latest			\
Version:	%{kversion}				\
Release:	%{rpmrel}				\
Summary:	Virtual rpm for latest %{kname}-%{1}-devel \
Group:		Development/Kernel			\
Requires:	%{kname}-%{1}-devel-%{buildrel}		\
%ifarch %{ix86}						\
Conflicts:	arch(x86_64)				\
%endif							\
Provides:	%{kname}-devel-latest			\
%{expand:%%{?latest_obsoletes_devel_%{1}:Obsoletes: %{latest_obsoletes_devel_%{1}}}} \
%{expand:%%{?latest_provides_devel_%{1}:Provides: %{latest_provides_devel_%{1}}}} \
%description -n %{kname}-%{1}-devel-latest		\
This package is a virtual rpm that aims to make sure you always have the \
latest %{kname}-%{1}-devel installed...			\
							\
%endif							\
							\
%posttrans -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1}-posttrans \
%preun -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1}-preun \
%postun -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1}-postun \
							\
%if %build_devel					\
%post -n %{kname}-%{1}-devel-%{buildrel} -f kernel_devel_files.%{1}-post \
%preun -n %{kname}-%{1}-devel-%{buildrel} -f kernel_devel_files.%{1}-preun \
%postun -n %{kname}-%{1}-devel-%{buildrel} -f kernel_devel_files.%{1}-postun \
%endif							\
							\
%files -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1} \
%files -n %{kname}-%{1}-latest				\
							\
%if %build_devel					\
%files -n %{kname}-%{1}-devel-%{buildrel} -f kernel_devel_files.%{1} \
%files -n %{kname}-%{1}-devel-latest			\
%endif							\
							\
%if %build_debug					\
%files -n %{kname}-%{1}-%{buildrel}-debuginfo -f kernel_debug_files.%{1} \
%endif

%ifarch %{ix86}
#
# kernel-desktop586: i586, smp-alternatives, 4GB
#
%if %build_desktop586
%define summary_desktop586 Linux kernel for desktop use with i586 and less than 4GB RAM
%define info_desktop586 This kernel is compiled for desktop use, single or \
multiple i586 processor(s)/core(s) and less than 4GB RAM (usually 3-3.5GB \
detected, if you need/want to use all 4GB or more, install kernel-server), \
using HZ_1000, voluntary preempt, CFS cpu scheduler and cfq i/o scheduler.
%mkflavour desktop586
%endif
%endif

#
# kernel-desktop: i686, smp-alternatives, 4 GB / x86_64
#
%if %build_desktop
%ifarch %{ix86}
%define summary_desktop Linux Kernel for desktop use with i686 and less than 4GB RAM
%define info_desktop This kernel is compiled for desktop use, single or \
multiple i686 processor(s)/core(s) and less than 4GB RAM (usually 3-3.5GB \
detected, if you need/want to use all 4GB or more, install kernel-server), \
using HZ_1000, voluntary preempt, CFS cpu scheduler and cfq i/o scheduler.
%else
%define summary_desktop Linux Kernel for desktop use with %{_arch}
%define info_desktop This kernel is compiled for desktop use, single or \
multiple %{_arch} processor(s)/core(s), using HZ_1000, voluntary preempt, \
CFS cpu scheduler and cfq i/o scheduler.
%endif
%mkflavour desktop
%endif

#
# kernel-server: i686, smp-alternatives, 64 GB / x86_64
#
%if %build_server
%ifarch %{ix86}
%define summary_server Linux Kernel for server use with i686 & 64GB RAM
%define info_server This kernel is compiled for server use, single or \
multiple i686 processor(s)/core(s) and up to 64GB RAM using PAE, using \
no preempt, HZ_100, CFS cpu scheduler and cfq i/o scheduler.
%else
%define summary_server Linux Kernel for server use with %{_arch}
%define info_server This kernel is compiled for server use, single or \
multiple %{_arch} processor(s)/core(s), using no preempt, HZ_100, \
CFS cpu scheduler and cfq i/o scheduler.
%endif
%mkflavour server
%endif

#
# ARM kernels
#
%ifarch %{arm}
%if %build_iop32x
%define summary_iop32x Linux Kernel for Arm machines based on Xscale IOP32X
%define info_iop32x This kernel is compiled for iop32x boxes. It will run on n2100 \
or ss4000e or sanmina boards.
%mkflavour iop32x
%endif
%if %build_kirkwood
%define summary_kirkwood Linux Kernel for Arm machines based on Kirkwood
%define info_kirkwood This kernel is compiled for kirkwood boxes. It will run on openrd boards.
%mkflavour kirkwood
%endif
%if %build_versatile
%define summary_versatile Linux Kernel for Versatile arm machines
%define info_versatile This kernel is compiled for Versatile boxes. It will run on Qemu for instance.
%mkflavour versatile
%endif
%endif

#
# kernel-source
#
%if %build_source
%package -n %{kname}-source-%{buildrel}
Version: 	%{fakever}
Release: 	%{fakerel}
Requires: 	glibc-devel, ncurses-devel, make, gcc, perl, diffutils
Summary: 	The Linux source code for %{kname}-%{buildrel}
Group: 		Development/Kernel
Autoreqprov: 	no
Provides: 	kernel-source = %{kverrel}
Buildarch:	noarch

%description -n %{kname}-source-%{buildrel}
The %{kname}-source package contains the source code files for the Mageia
kernel. Theese source files are only needed if you want to build your
own custom kernel that is better tuned to your particular hardware.

If you only want the files needed to build 3rdparty (nVidia, Ati, dkms-*,...)
drivers against, install the *-devel-* rpm that is matching your kernel.

#
# kernel-source-latest: virtual rpm
#
%package -n %{kname}-source-latest
Version: 	%{kversion}
Release: 	%{rpmrel}
Summary: 	Virtual rpm for latest %{kname}-source
Group:   	Development/Kernel
Requires: 	%{kname}-source-%{buildrel}
Buildarch:	noarch

%description -n %{kname}-source-latest
This package is a virtual rpm that aims to make sure you always have the
latest %{kname}-source installed...
%endif

#
# kernel-doc: documentation for the Linux kernel
#
%if %build_doc
%package -n %{kname}-doc
Version: 	%{kversion}
Release: 	%{rpmrel}
Summary: 	Various documentation bits found in the %{kname} source
Group: 		Documentation
Buildarch:	noarch

%description -n %{kname}-doc
This package contains documentation files from the %{kname} source.
Various bits of information about the Linux kernel and the device drivers
shipped with it are documented in these files. You also might want install
this package if you need a reference to the options that can be passed to
Linux kernel modules at load time.
%endif

#
# kernel/tools
#
%if %{build_perf}
%package -n perf
Version:	%{kversion}
Release:	%{rpmrel}
Summary:	perf tool and the supporting documentation
Group:		System/Kernel and hardware

%description -n perf
the perf tool and the supporting documentation.
%endif

%if %{build_cpupower}
%package -n cpupower
Version:	%{kversion}
Release:	%{rpmrel}
Summary:	the cpupower tools
Group:		System/Kernel and hardware
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
Obsoletes:	cpufreq cpufrequtils

%description -n cpupower
the cpupower tools.

%post -n cpupower
%_post_service cpupower

%preun -n cpupower
%_preun_service cpupower

%package -n cpupower-devel
Version:	%{kversion}
Release:	%{rpmrel}
Summary:	devel files for cpupower
Group:		Development/Kernel
Requires:	cpupower = %{kversion}-%{rpmrel}
Conflicts:	%{_lib}cpufreq-devel

%description -n cpupower-devel
This package contains the development files for cpupower.
%endif


#
# End packages - here begins build stage
#
%prep
%setup -q -n %top_dir_name -c
%setup -q -n %top_dir_name -D -T -a100

%define patches_dir ../%{patch_ver}/

cd %src_dir

%if %sublevel
%if %kpatch
%if %prev_sublevel
%patch1 -p1
%endif
%patch2 -p1
%else
%patch1 -p1
%endif
%else
%if %kpatch
%patch1 -p1
%endif
%endif
%if %kgit
%patch2 -p1
%endif
%if %extstable
%patch3 -p1
%endif

%{patches_dir}/scripts/apply_patches

# PATCH END


#
# Setup Begin
#

# Prepare all the variables for calling create_configs

%if %build_debug
%define debug --debug
%else
%define debug --no-debug
%endif


%{patches_dir}/scripts/create_configs %debug --user_cpu="%{target_arch}"

# make sure the kernel has the sublevel we know it has...
LC_ALL=C perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile

# get rid of unwanted files
find . -name '*~' -o -name '*.orig' -o -name '*.append' | %kxargs rm -f


%build
# Common target directories
%define _kerneldir /usr/src/kernel-%{kversion}-%{buildrpmrel}
%define _bootdir /boot
%define _modulesdir /lib/modules
%define _efidir %{_bootdir}/efi/mageia

# Directories definition needed for building
%define temp_root %{build_dir}/temp-root
%define temp_source %{temp_root}%{_kerneldir}
%define temp_boot %{temp_root}%{_bootdir}
%define temp_modules %{temp_root}%{_modulesdir}

PrepareKernel() {
	name=$1
	extension=$2
	x86_dir=arch/x86/configs

	echo "Make config for kernel $extension"

	%smake -s mrproper

	if [ "%{target_arch}" == "i386" -o "%{target_arch}" == "x86_64" ]; then
	    if [ -z "$name" ]; then
		cp ${x86_dir}/%{target_arch}_defconfig-desktop .config
	    else
		cp ${x86_dir}/%{target_arch}_defconfig-$name .config
	    fi
	else
	    if [ -z "$name" ]; then
		cp arch/%{target_arch}/defconfig-desktop .config
	    else
		cp arch/%{target_arch}/defconfig-$name .config
	    fi
	fi

	# make sure EXTRAVERSION says what we want it to say
	%if %extstable
	LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = .%{extstable}-$extension/" Makefile
	%else
	LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -$extension/" Makefile
	%endif

	%smake oldconfig
}

BuildKernel() {
	KernelVer=$1

	echo "Building kernel $KernelVer"

	%kmake -s all

	%ifarch %{arm}
	make dtbs
	%endif

	# Start installing stuff
	install -d %{temp_boot}
	install -m 644 System.map %{temp_boot}/System.map-$KernelVer
	install -m 644 .config %{temp_boot}/config-$KernelVer
	xz -c Module.symvers > %{temp_boot}/symvers-$KernelVer.xz

	%ifarch %{arm}
		cp -f arch/arm/boot/zImage %{temp_boot}/vmlinuz-$KernelVer
		install -d %{temp_root}/usr/lib/linux-$KernelVer/
		for d in arch/arm/boot/dts/*.dtb; do \
			install -D -m644 $d %{temp_root}/usr/lib/linux-$KernelVer/$(basename $d); \
		done
	%else
		cp -f arch/%{target_arch}/boot/bzImage %{temp_boot}/vmlinuz-$KernelVer
	%endif

	# modules
	install -d %{temp_modules}/$KernelVer
	%smake INSTALL_MOD_PATH=%{temp_root} KERNELRELEASE=$KernelVer modules_install

	# remove /lib/firmware, we use a separate kernel-firmware
	rm -rf %{temp_root}/lib/firmware
}

SaveDevel() {
	devel_flavour=$1

	DevelRoot=/usr/src/kernel-%{kversion}-$devel_flavour-%{buildrpmrel}
	TempDevelRoot=%{temp_root}$DevelRoot

	mkdir -p $TempDevelRoot
	for i in $(find . -name 'Makefile*'); do cp -R --parents $i $TempDevelRoot;done
	for i in $(find . -name 'Kconfig*' -o -name 'Kbuild*'); do cp -R --parents $i $TempDevelRoot;done
	cp -fR include $TempDevelRoot
	cp -fR scripts $TempDevelRoot
	cp -fR kernel/bounds.c $TempDevelRoot/kernel
	cp -fR tools/include $TempDevelRoot/tools/
	%ifarch %{arm}
		cp -fR arch/%{target_arch}/tools $TempDevelRoot/arch/%{target_arch}/
	%endif
	%ifarch %{ix86} x86_64
		cp -fR arch/x86/kernel/asm-offsets.{c,s} $TempDevelRoot/arch/x86/kernel/
		cp -fR arch/x86/kernel/asm-offsets_{32,64}.c $TempDevelRoot/arch/x86/kernel/
		cp -fR arch/x86/syscalls/syscall* $TempDevelRoot/arch/x86/syscalls/
		cp -fR arch/x86/include $TempDevelRoot/arch/x86/
		cp -fR arch/x86/tools $TempDevelRoot/arch/x86/
	%else
		cp -fR arch/%{target_arch}/kernel/asm-offsets.{c,s} $TempDevelRoot/arch/%{target_arch}/kernel/
		for f in $(find arch/%{target_arch} -name include); do cp -fR --parents $f $TempDevelRoot; done
	%endif
	cp -fR .config Module.symvers $TempDevelRoot
	cp -fR 3rdparty/mkbuild.pl $TempDevelRoot/3rdparty

	# Needed for truecrypt build (Danny)
	cp -fR drivers/md/dm.h $TempDevelRoot/drivers/md/

	# Needed for lguest
	cp -fR drivers/lguest/lg.h $TempDevelRoot/drivers/lguest/

	# Needed for lirc_gpio (#39004)
	cp -fR drivers/media/pci/bt8xx/bttv{,p}.h $TempDevelRoot/drivers/media/pci/bt8xx/
	cp -fR drivers/media/pci/bt8xx/bt848.h $TempDevelRoot/drivers/media/pci/bt8xx/
	cp -fR drivers/media/common/btcx-risc.h $TempDevelRoot/drivers/media/common/

	# Needed for external dvb tree (#41418)
	cp -fR drivers/media/dvb-core/*.h $TempDevelRoot/drivers/media/dvb-core/
	cp -fR drivers/media/dvb-frontends/lgdt330x.h $TempDevelRoot/drivers/media/dvb-frontends/

	# add acpica header files, needed for fglrx build
	cp -fR drivers/acpi/acpica/*.h $TempDevelRoot/drivers/acpi/acpica/

	# aufs2 has a special file needed
	cp -fR fs/aufs/magic.mk $TempDevelRoot/fs/aufs

	for i in alpha arc avr32 blackfin c6x cris frv h8300 hexagon ia64 m32r m68k m68knommu metag microblaze \
		 mips mn10300 openrisc parisc powerpc s390 score sh sparc tile unicore32 xtensa; do
		rm -rf $TempDevelRoot/arch/$i
	done

	%ifnarch %{arm}
		rm -rf $TempDevelRoot/arch/arm*
		rm -rf $TempDevelRoot/include/kvm/arm*
	%endif
	%ifnarch %{ix86} x86_64
		rm -rf $TempDevelRoot/arch/x86
	%endif

	# Clean the scripts tree, and make sure everything is ok (sanity check)
	# running prepare+scripts (tree was already "prepared" in build)
	pushd $TempDevelRoot >/dev/null
		%smake -s prepare scripts
		%smake -s clean
	popd >/dev/null
	rm -f $TempDevelRoot/.config.old

	# fix permissions
	chmod -R a+rX $TempDevelRoot

	# disable mrproper in -devel rpms
	patch -p1 --fuzz=0 -d $TempDevelRoot -i %{SOURCE2}

	kernel_devel_files=../kernel_devel_files.$devel_flavour


### Create the kernel_devel_files.*
cat > $kernel_devel_files <<EOF
%dir $DevelRoot
%dir $DevelRoot/arch
%dir $DevelRoot/include
$DevelRoot/3rdparty
$DevelRoot/Documentation
%ifarch %{arm}
$DevelRoot/arch/arm
$DevelRoot/arch/arm64
%endif
$DevelRoot/arch/um
%ifarch %{ix86} x86_64
$DevelRoot/arch/x86
%endif
$DevelRoot/block
$DevelRoot/crypto
$DevelRoot/drivers
$DevelRoot/firmware
$DevelRoot/fs
$DevelRoot/include/Kbuild
$DevelRoot/include/acpi
$DevelRoot/include/asm-generic
$DevelRoot/include/clocksource
$DevelRoot/include/config
$DevelRoot/include/crypto
$DevelRoot/include/drm
$DevelRoot/include/dt-bindings
$DevelRoot/include/generated
$DevelRoot/include/keys
$DevelRoot/include/linux
$DevelRoot/include/math-emu
$DevelRoot/include/media
$DevelRoot/include/memory
$DevelRoot/include/misc
$DevelRoot/include/net
$DevelRoot/include/pcmcia
$DevelRoot/include/ras
$DevelRoot/include/rdma
$DevelRoot/include/rxrpc
$DevelRoot/include/scsi
$DevelRoot/include/sound
$DevelRoot/include/target
$DevelRoot/include/trace
$DevelRoot/include/uapi
$DevelRoot/include/video
$DevelRoot/include/xen
$DevelRoot/init
$DevelRoot/ipc
$DevelRoot/kernel
$DevelRoot/lib
$DevelRoot/mm
$DevelRoot/net
$DevelRoot/samples
$DevelRoot/scripts
$DevelRoot/security
$DevelRoot/sound
$DevelRoot/tools
$DevelRoot/usr
$DevelRoot/virt
$DevelRoot/.config
$DevelRoot/Kbuild
$DevelRoot/Kconfig
$DevelRoot/Makefile
$DevelRoot/Module.symvers
$DevelRoot/arch/Kconfig
%doc README.kernel-sources
EOF


### Create -devel Post script on the fly
cat > $kernel_devel_files-post <<EOF
if [ -d /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel} ]; then
	rm -f /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/{build,source}
	ln -sf $DevelRoot /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/build
	ln -sf $DevelRoot /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/source
fi
EOF


### Create -devel Preun script on the fly
cat > $kernel_devel_files-preun <<EOF
if [ -L /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/build ]; then
	rm -f /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/build
fi
if [ -L /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/source ]; then
	rm -f /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/source
fi
exit 0
EOF

### Create -devel Postun script on the fly
cat > $kernel_devel_files-postun <<EOF
rm -rf /usr/src/kernel-%{kversion}-$devel_flavour-%{buildrpmrel} >/dev/null
EOF
}

SaveDebug() {
	debug_flavour=$1

	install -m 644 vmlinux \
	      %{temp_boot}/vmlinux-%{kversion}-$debug_flavour-%{buildrpmrel}
	kernel_debug_files=../kernel_debug_files.$debug_flavour
	echo "%{_bootdir}/vmlinux-%{kversion}-$debug_flavour-%{buildrpmrel}" \
		>> $kernel_debug_files

	find %{temp_modules}/%{kversion}-$debug_flavour-%{buildrpmrel}/kernel \
		-name "*.ko" | \
		%kxargs -I '{}' objcopy --only-keep-debug '{}' '{}'.debug
	find %{temp_modules}/%{kversion}-$debug_flavour-%{buildrpmrel}/kernel \
		-name "*.ko" | %kxargs -I '{}' \
		sh -c 'cd `dirname {}`; \
		       objcopy --add-gnu-debuglink=`basename {}`.debug \
		       --strip-debug `basename {}`'

	pushd %{temp_modules}
	find %{kversion}-$debug_flavour-%{buildrpmrel}/kernel \
		-name "*.ko.debug" > debug_module_list
	popd
	cat %{temp_modules}/debug_module_list | \
		sed 's|\(.*\)|%{_modulesdir}/\1|' >> $kernel_debug_files
	cat %{temp_modules}/debug_module_list | \
		sed 's|\(.*\)|%exclude %{_modulesdir}/\1|' \
		>> ../kernel_exclude_debug_files.$debug_flavour
	rm -f %{temp_modules}/debug_module_list
}

CreateFiles() {
	kernel_flavour=$1

	kernel_files=../kernel_files.$kernel_flavour

ker="vmlinuz"
### Create the kernel_files.*
cat > $kernel_files <<EOF
%{_bootdir}/System.map-%{kversion}-$kernel_flavour-%{buildrpmrel}
%{_bootdir}/symvers-%{kversion}-$kernel_flavour-%{buildrpmrel}.xz
%{_bootdir}/config-%{kversion}-$kernel_flavour-%{buildrpmrel}
%{_bootdir}/$ker-%{kversion}-$kernel_flavour-%{buildrpmrel}
%dir %{_modulesdir}/%{kversion}-$kernel_flavour-%{buildrpmrel}/
%{_modulesdir}/%{kversion}-$kernel_flavour-%{buildrpmrel}/kernel
%{_modulesdir}/%{kversion}-$kernel_flavour-%{buildrpmrel}/modules.*
%doc README.kernel-sources
%ifarch %arm
%dir /usr/lib/linux-%{kversion}-$kernel_flavour-%{buildrpmrel}
/usr/lib/linux-%{kversion}-$kernel_flavour-%{buildrpmrel}/*.dtb
%endif
EOF

%if %build_debug
    cat ../kernel_exclude_debug_files.$kernel_flavour >> $kernel_files
%endif

### Create kernel Posttrans script
cat > $kernel_files-posttrans <<EOF
%if %build_devel
# create kernel-devel symlinks if matching -devel- rpm is installed
if [ -d /usr/src/kernel-%{kversion}-$kernel_flavour-%{buildrpmrel} ]; then
	rm -f /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/{build,source}
	ln -sf /usr/src/kernel-%{kversion}-$kernel_flavour-%{buildrpmrel} /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/build
	ln -sf /usr/src/kernel-%{kversion}-$kernel_flavour-%{buildrpmrel} /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/source
fi
%endif
if [ -x /usr/sbin/dkms_autoinstaller -a -d /usr/src/kernel-%{kversion}-$kernel_flavour-%{buildrpmrel} ]; then
    /usr/sbin/dkms_autoinstaller start %{kversion}-$kernel_flavour-%{buildrpmrel}
fi
%ifarch %{arm}
/sbin/installkernel -i -N %{kversion}-$kernel_flavour-%{buildrpmrel}
%else
/sbin/installkernel %{kversion}-$kernel_flavour-%{buildrpmrel}
pushd /boot > /dev/null
if [ -L vmlinuz-$kernel_flavour ]; then
	rm -f vmlinuz-$kernel_flavour
fi
ln -sf vmlinuz-%{kversion}-$kernel_flavour-%{buildrpmrel} vmlinuz-$kernel_flavour
if [ -L initrd-$kernel_flavour.img ]; then
	rm -f initrd-$kernel_flavour.img
fi
ln -sf initrd-%{kversion}-$kernel_flavour-%{buildrpmrel}.img initrd-$kernel_flavour.img
popd > /dev/null
%endif
EOF

### Create kernel Preun script on the fly
cat > $kernel_files-preun <<EOF
/sbin/installkernel -R %{kversion}-$kernel_flavour-%{buildrpmrel}
pushd /boot > /dev/null
if [ -L vmlinuz-$kernel_flavour ]; then
	if [ "$(readlink vmlinuz-$kernel_flavour)" = "vmlinuz-%{kversion}-$kernel_flavour-%{buildrpmrel}" ]; then
		rm -f vmlinuz-$kernel_flavour
	fi
fi
if [ -L initrd-$kernel_flavour.img ]; then
	if [ "$(readlink initrd-$kernel_flavour.img)" = "initrd-%{kversion}-$kernel_flavour-%{buildrpmrel}.img" ]; then
		rm -f initrd-$kernel_flavour.img
	fi
fi
popd > /dev/null
%if %build_devel
if [ -L /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/build ]; then
	rm -f /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/build
fi
if [ -L /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/source ]; then
	rm -f /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/source
fi
%endif
exit 0
EOF


### Create kernel Postun script on the fly
cat > $kernel_files-postun <<EOF
/sbin/kernel_remove_initrd %{kversion}-$kernel_flavour-%{buildrpmrel}
rm -rf /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel} >/dev/null
if [ -d /var/lib/dkms ]; then
    rm -f /var/lib/dkms/*/kernel-%{kversion}-$devel_flavour-%{buildrpmrel}-%{_target_cpu} >/dev/null
    rm -rf /var/lib/dkms/*/*/%{kversion}-$devel_flavour-%{buildrpmrel} >/dev/null
    rm -f /var/lib/dkms-binary/*/kernel-%{kversion}-$devel_flavour-%{buildrpmrel}-%{_target_cpu} >/dev/null
    rm -rf /var/lib/dkms-binary/*/*/%{kversion}-$devel_flavour-%{buildrpmrel} >/dev/null
fi
EOF
}


CreateKernel() {
	flavour=$1

	PrepareKernel $flavour $flavour-%{buildrpmrel}

	BuildKernel %{kversion}-$flavour-%{buildrpmrel}
	%if %build_devel
		SaveDevel $flavour
	%endif
	%if %build_debug
		SaveDebug $flavour
	%endif
	CreateFiles $flavour
}


###
# DO it...
###


# Create a simulacro of buildroot
rm -rf %{temp_root}
install -d %{temp_root}


# make sure we are in the directory
cd %src_dir

%ifarch %{ix86}
%if %build_desktop586
CreateKernel desktop586
%endif
%endif

%if %build_desktop
CreateKernel desktop
%endif

%if %build_server
CreateKernel server
%endif

%ifarch %{arm}
%if %build_iop32x
CreateKernel iop32x
%endif
%if %build_kirkwood
CreateKernel kirkwood
%endif
%if %build_versatile
CreateKernel versatile
%endif
%endif

# set extraversion to match srpm to get nice version reported by the tools
%if %extstable
LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = .%{extstable}-%{rpmrel}/" Makefile
%else
LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{rpmrel}/" Makefile
%endif
# build perf
%if %{build_perf}
# perf
%smake -C tools/perf -s HAVE_CPLUS_DEMANGLE=1 prefix=%{_prefix} all
%smake -C tools/perf -s prefix=%{_prefix} man
%endif

%if %{build_cpupower}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
%make -C tools/power/cpupower CPUFREQ_BENCH=false
%endif

# We don't make to repeat the depend code at the install phase
%if %build_source
%ifarch %{arm}
    PrepareKernel "kirkwood" %{buildrpmrel}custom
%else
    PrepareKernel "" %{buildrpmrel}custom
%endif
%smake -s mrproper
%endif


###
### install
###
%install
install -m 644 %{SOURCE4}  .

cd %src_dir

# Directories definition needed for installing
%define target_source %{buildroot}%{_kerneldir}
%define target_boot %{buildroot}%{_bootdir}
%define target_modules %{buildroot}%{_modulesdir}

# We want to be able to test several times the install part
rm -rf %{buildroot}
cp -a %{temp_root} %{buildroot}

# Create directories infastructure
%if %build_source
install -d %{target_source}

tar cf - . | tar xf - -C %{target_source}
chmod -R a+rX %{target_source}

# we remove all the source files that we don't ship
# first architecture files
for i in alpha arc avr32 blackfin c6x cris frv h8300 hexagon ia64 m32r m68k m68knommu metag microblaze \
	 mips openrisc parisc powerpc s390 score sh sh64 sparc tile unicore32 v850 xtensa mn10300; do
	rm -rf %{target_source}/arch/$i
done
%ifnarch %{arm}
	rm -rf %{target_source}/include/kvm/arm*
%endif

# other misc files
rm -f %{target_source}/{.config.old,.config.cmd,.gitignore,.lst,.mailmap}
rm -f %{target_source}/{.missing-syscalls.d,arch/.gitignore,firmware/.gitignore}
rm -rf %{target_source}/.tmp_depmod/

#endif %build_source
%endif

# compressing modules
%if %{build_modxz}
find %{target_modules} -name "*.ko" | %kxargs xz -6e
%else
find %{target_modules} -name "*.ko" | %kxargs gzip -9
%endif

# We used to have a copy of PrepareKernel here
# Now, we make sure that the thing in the linux dir is what we want it to be
for i in %{target_modules}/*; do
	rm -f $i/build $i/source
done

# sniff, if we compressed all the modules, we change the stamp :(
# we really need the depmod -ae here
pushd %{target_modules}
for i in *; do
	/sbin/depmod -ae -b %{buildroot} -F %{target_boot}/System.map-$i $i
	echo $?
done

for i in *; do
	pushd $i
	echo "Creating modules.description for $i"
	modules=`find . -name "*.ko.[g,x]z"`
	echo $modules | %kxargs /sbin/modinfo \
	| perl -lne 'print "$name\t$1" if $name && /^description:\s*(.*)/; $name = $1 if m!^filename:\s*(.*)\.k?o!; $name =~ s!.*/!!' > modules.description
	popd
done
popd

# need to set extraversion to match srpm again to avoid rebuild
%if %extstable
LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = .%{extstable}-%{rpmrel}/" Makefile
%else
LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{rpmrel}/" Makefile
%endif
%if %{build_perf}
# perf tool binary and supporting scripts/binaries
make -C tools/perf -s V=1 DESTDIR=%{buildroot} HAVE_CPLUS_DEMANGLE=1 prefix=%{_prefix} install

# perf man pages (note: implicit rpm magic compresses them later)
make -C tools/perf  -s V=1 DESTDIR=%{buildroot} HAVE_CPLUS_DEMANGLE=1 prefix=%{_prefix} install-man
%endif

%if %{build_cpupower}
make -C tools/power/cpupower DESTDIR=%{buildroot} libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
rm -f %{buildroot}%{_libdir}/*.{a,la}
%find_lang cpupower
mv cpupower.lang ../
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -m644 %{SOURCE50} %{buildroot}%{_unitdir}/cpupower.service
install -m644 %{SOURCE51} %{buildroot}%{_sysconfdir}/sysconfig/cpupower
%endif

###
### clean
###
%clean
rm -rf %{buildroot}


# We don't want to remove this, the whole reason of its existence is to be
# able to do several rpm --short-circuit -bi for testing install
# phase without repeating compilation phase
#rm -rf %{temp_root}

###
### source and doc file lists
###

%if %build_source
%files -n %{kname}-source-%{buildrel}
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/3rdparty
%{_kerneldir}/Documentation
%{_kerneldir}/arch/Kconfig
%{_kerneldir}/arch/arm
%{_kerneldir}/arch/arm64
%{_kerneldir}/arch/um
%{_kerneldir}/arch/x86
%{_kerneldir}/block
%{_kerneldir}/crypto
%{_kerneldir}/drivers
%{_kerneldir}/firmware
%{_kerneldir}/fs
%{_kerneldir}/include/Kbuild
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm-generic
%{_kerneldir}/include/clocksource
%{_kerneldir}/include/crypto
%{_kerneldir}/include/drm
%{_kerneldir}/include/dt-bindings
%{_kerneldir}/include/keys
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/media
%{_kerneldir}/include/memory
%{_kerneldir}/include/misc
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/ras
%{_kerneldir}/include/rdma
%{_kerneldir}/include/rxrpc
%{_kerneldir}/include/scsi
%{_kerneldir}/include/sound
%{_kerneldir}/include/target
%{_kerneldir}/include/trace
%{_kerneldir}/include/uapi
%{_kerneldir}/include/video
%{_kerneldir}/include/xen
%{_kerneldir}/init
%{_kerneldir}/ipc
%{_kerneldir}/kernel
%{_kerneldir}/lib
%{_kerneldir}/mm
%{_kerneldir}/net
%{_kerneldir}/virt
%{_kerneldir}/samples
%{_kerneldir}/scripts
%{_kerneldir}/security
%{_kerneldir}/sound
%{_kerneldir}/tools
%{_kerneldir}/usr
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Kbuild
%{_kerneldir}/Kconfig
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
%{_kerneldir}/REPORTING-BUGS
%doc README.kernel-sources

%files -n %{kname}-source-latest
%endif

%if %build_doc
%files -n %{kname}-doc
%doc linux-%{tar_ver}/Documentation/*
%endif

%if %{build_perf}
%files -n perf
%{_bindir}/perf
%{_bindir}/trace
%dir %{_prefix}/libexec/perf-core
%{_libdir}/libperf-gtk.so
%dir %{_libdir}/traceevent
%dir %{_libdir}/traceevent/plugins
%{_libdir}/traceevent/plugins/*
%{_prefix}/libexec/perf-core/*
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf
%endif

%if %{build_cpupower}
%files -n cpupower -f cpupower.lang
%{_bindir}/cpupower
%{_libdir}/libcpupower.so.0
%{_libdir}/libcpupower.so.0.0.0
%{_unitdir}/cpupower.service
%{_mandir}/man[1-8]/cpupower*
%config(noreplace) %{_sysconfdir}/sysconfig/cpupower

%files -n cpupower-devel
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%endif


%changelog
* Thu May 07 2015 tmb <tmb> 3.14.41-1.mga4
+ Revision: 821381
- ipv4: Missing sk_nulls_node_init() in ping_unhash() (CVE-2015-3636)
- aufs: adapt for d_u.d_child -> d_child change in 3.14.40
- update to 3.14.41
- require fixed dracut from MGAA-2015-0041
- update to 3.14.39
  * drop merged patches
- btrfs: simplify insert_orphan_item (fixes boot hang)
- IB/uverbs: Prevent integer overflow in ib_umem_get address
  arithmetic (CVE-2014-8159)
- update to 3.14.37
  * drop merged patches
- ipv4: try to cache dst_entries which would cause a redirect
  (CVE-2015-1465)
- net: sctp: fix slab corruption from use after free on INIT collisions
  (CVE-2015-1421)
- update to 3.14.32
- ntp: Fixup adjtimex freq validation on 32bit systems (mga#14174)
- update to 3.14.31
- update to 3.14.30
  * drop merged patches
- enable SUNRPC_DEBUG
- net: prevent of emerging cross-namespace symlinks
- net: fix creation adjacent device symlinks
- fsnotify: next_i is freed during fsnotify_unmount_inodes
- update to 3.14.29
  * drop merged patches
- btrfs: fix fs corruption on transaction abort if device supports discard
- isofs: Fix infinite looping over CE entries
- x86_64, switch_to(): Load TLS descriptors before switching DS and ES
- x86/tls: Disallow unusual TLS segments
- x86/tls: Validate TLS entries to protect espfix (CVE-2014-8133)
- x86, kvm: Clear paravirt_enabled on KVM guests for espfix32's benefit
  (CVE-2014-8134)
- update to 3.14.27
- drm/i915: Disable RCS flips on Ivybridge
- update to 3.14.25
- drop merged patches
- Revert "drivers/net: Disable UFO through virtio" as it breaks
  VM migration
- add ahci support for Intel Sunrise Point / Skylake
- make INTEL_MEI modular (mga#14469)
- update to 3.14.24
- drop merged patch
- update to 3.14.23
- rebuild for unversioned kmod provides (mga#14235)
- switch to performance governor
- mnt: Prevent pivot_root from creating a loop in the mount tree (CVE-2014-7970)
- update to 3.14.22
- fs: Add a missing permission check to do_umount (CVE-2014-7975)
- update to 3.14.21
- drop merged patches
- add current -stable queue
- update to 3.14.19
- drop merged patches
- disable X86_SYSFB as it breaks KMS on some systems (mga#13098)
- pull in -stable queue
- ahci: Add Device IDs for Intel 9 Series PCH
- ata_piix: Add Device IDs for Intel 9 Series PCH
- ahci: add pcid for Marvel 0x9182 controller
- ata: Disabling the async PM for JMicron chip 363/361
- md/raid1: be more cautious where we read-balance during resync
- md/raid1: make sure resync waits for conflicting writes to complete
- export do_fallocate symbol for aufs
- update aufs to 3.14 branch
- revert: 'usb: gadget: f_fs: resurect usb_functionfs_descs_head structure'
  as it actually duplicates definition and breaks userspace builds
- drop merged patches
- update to 3.14.18
- ACPI / battery: add quirk for Acer Aspire V5-573G
- ACPI / video: Add Acer TravelMate B113 to native backlight blacklist
- ACPI / video: Add Dell Inspiron 5737 to the blacklist
- ACPI / video: Add use_native_backlight quirk for HP EliteBook 2014 models
- ACPI / video: Add use_native_backlight quirk for HP ProBook 4540s
- mac80211: reset probe_send_count also in HW_CONNECTION_MONITOR case
- libata: widen Crucial M550 queued trim blacklist matching
- Btrfs: read lock extent buffer while walking backrefs
- Btrfs: fix compressed write corruption on enospc
- Btrfs: fix csum tree corruption, duplicate and outdated checksums
- revert 'iwlwifi: dvm: don't enable CTS to self' as it is reported to
  cause a big packet loss on some hw
- md/raid6: avoid data corruption during recovery of double-degraded RAID6
- md/raid10: fix memory leak when reshaping a RAID10
- md/raid10: Fix memory leak when raid10 reshape completes
- md/raid10: avoid memory leak on error path during reshape
- md/raid10: always initialise ->state on newly allocated r10_bio
- add current -stable queue fixes
- conflict older kernel-firmware-nonfree to get updated ones in initrd
- update conflicts on radeon-fimware to get new firmwares added in initrd
- fix typo in dkms-xtables-addons conflict
- update conflicts on dkms packages and btrfs-progs to match kernel 3.14
- update filelists
- update to 3.14.17 -longterm
- drop merged/obsolete patches
- add 3.14 buildfixes for ndiswrapper and mach64
- rebase aufs, overlayfs, mach64 and shuttle-wmi patches
- add r8192ee wireless driver
- update defconfigs
- update to 3.12.26
- drop merged patches
- net: sctp: inherit auth_capable on INIT collisions (CVE-2014-5077)
- fs: umount on symlink leaks mnt count (CVE-2014-5045)
- 8021q: fix a potential memory leak
- alarmtimer: Fix bug where relative alarm timers were treated as absolute
- appletalk: Fix socket referencing in skb
- ARC: Implement ptrace(PTRACE_GET_THREAD_AREA)
- be2net: set EQ DB clear-intr bit in be_open()
- bnx2x: fix possible panic under memory stress
- dm cache metadata: do not allow the data block size to change
- dm thin metadata: do not allow the data block size to change
- dns_resolver: assure that dns_query() result is null-terminated
- dns_resolver: Null-terminate the right string
- drm/qxl: return IRQ_NONE if it was not our irq
- drm/radeon: avoid leaking edid data
- drm/radeon: set default bl level to something reasonable
- igmp: fix the problem when mc leave group
- ip_tunnel: fix ip_tunnel_lookup
- ipv4: fix buffer overflow in ip_options_compile()
- ipv4: fix dst race in sk_dst_get()
- ipv4: icmp: Fix pMTU handling for rare case
- ipv4: irq safe sk_dst_[re]set() and ipv4_sk_update_pmtu() fix
- irqchip: gic: Add support for cortex a7 compatible string
- irqchip: gic: Fix core ID calculation when topology is read from DT
- mwifiex: fix Tx timeout issue
- net: fix sparse warning in sk_dst_set()
- net: mvneta: Fix big endian issue in mvneta_txq_desc_csum()
- net: mvneta: fix operation in 10 Mbit/s mode
- net: pppoe: use correct channel MTU when using Multilink PPP
- net: qmi_wwan: Add ID for Telewell TW-LTE 4G v2
- net: qmi_wwan: add two Sierra Wireless/Netgear devices
- net: sctp: check proc_dointvec result in proc_sctp_do_auth
- net: sctp: fix information leaks in ulpevent layer
- perf/x86/intel: ignore CondChgd bit to avoid false NMI handling
- PM / sleep: Fix request_firmware() error at resume
- ring-buffer: Fix polling on trace_pipe
- sched: Fix possible divide by zero in avg_atom() calculation
- sunvnet: clean up objects created in vnet_new() on vnet_exit()
- tcp: Fix divide by zero when pushing during tcp-repair
- tcp: fix tcp_match_skb_to_sack() for unaligned SACK at end of an skb
- tipc: clear 'next'-pointer of message fragments before reassembly
- require fixed gcc
- bluetooth: Ignore H5 non-link packets in non-active state
- hv: util: Fix a bug in the KVP code
- fuse: handle large user and group ID
- hwmon: (adt7470) Fix writes to temperature limit registers
- hwmon: (da9052) Don't use dash in the name attribute
- hwmon: (da9055) Don't use dash in the name attribute
- igb: do a reset on SR-IOV re-init if device is down
- iwlwifi: dvm: don't enable CTS to self
- media: gspca_pac7302: Add new usb-id for Genius i-Look 317 (mga#13485)
- shmem: fix faulting into a hole, not taking i_mutex (CVE-2014-4171)
- shmem: fix faulting into a hole while it's punched (CVE-2014-4171)
- shmem: fix splicing from a hole while it's punched (CVE-2014-4171)
- tracing: Add ftrace_trace_stack into __trace_puts/__trace_bputs
- tracing: Fix graph tracer with stack tracer on other archs
- usb: Check if port status is equal to RxDetect
- update to 3.12.25
- drop merged patches
- x86_32, entry: store badsys error code in eax, fixes
  breakage introduced by CVE-2014-4508 fix
- iwlwifi: mvm: disable beacon filtering
- media: media-device: fix infoleak in ioctl media_enum_entities()
  (CVE-2014-1739)
- fix futex security issue (CVE-2014-3153)
- ALSA: hda - Fix onboard audio on Intel H97/Z97 chipsets
- update to 3.12.21
- disable AUDITSYSCALL as its broken beyond repair
  (avoids CVE-2014-3917, and other upcoming CVEs)
- drop merged patches
- update to 3.12.20
- require fixed kmod
- enable Intel P-state driver (mga#13080)
- update to 3.12.18
- switch transparent hugepages back to MADVISE
- net: ping: refcount issue in ping_init_sock() function (CVE-2014-2851)
- drop merged patches
- update to 3.12.17
- ALSA: hda - Add QEMU codec vendor ID
- sata_sil: apply MOD15WRITE quirk to TOSHIBA MK2561GSYN
- ata-pmp: enable quirk from jmicron JMB350 for JMB394
- ahci: disable NCQ on Samsung pci-e SSDs on macbooks
- Revert 'tty: Set correct tty name in 'active' sysfs attribute' as it breaks plymouth
- install source and devel as /usr/src/kernel-... to be more consistent with rpm name
- ACPICA: Add 'Windows 2013' string to _OSI support
- net: use __GFP_NORETRY for high order allocations
- enable MEMCG on server kernels (mga#12629)
- drop merged patches
- update to 3.12.13
- drop merged patches
- update to 3.12.12
- sync in kernel-3.12.9-1.mga4 from MGASA-2014-0039

* Fri Jan 24 2014 tmb <tmb> 3.12.8-2.mga4
+ Revision: 567732
- fix xen NUMA crash (3.12.7 regression, LKML)
- drm/radeon: add UVD support for OLAND
- update to 3.12.9-rc1
- drop merged patches

* Sun Jan 19 2014 tmb <tmb> 3.12.8-1.mga4
+ Revision: 566911
- revert: usbcore: set lpm_capable field for LPM capable root hubs
  (breaks some usb devices)
- revert: 'ACPI: Add BayTrail SoC GPIO and LPSS ACPI IDs' as it causes boot hangs
- x86, cpu: Add workaround for AMD F16h Erratum 793 (CVE-2013-6885)
- x86, quirks: Add workaround for AMD F16h Erratum 792
- x86 idle: restore mwait_idle()
- b43: fix the wrong assignment of status.freq in b43_rx()
- net, via-rhine: Fix tx_timeout handling
- net: rds: fix per-cpu helper usage
- hwmon: (coretemp) Fix truncated name of alarm attributes
- writeback: Fix data corruption on NFS
- fork: Allow CLONE_PARENT after setns(CLONE_NEWPID)
- vfs: In d_path don't call d_dname on a mount point
- vfs: Fix a regression in mounting proc
- md/raid5: Fix possible confusion when multiple write errors occur
- md/raid10: fix two bugs in handling of known-bad-blocks
- md/raid10: fix bug when raid10 recovery fails to recover a block
- md: fix problem when adding device to read-only array with bitmap
- allow 64 cores/threads on desktop586 kernel too (as its also used in installer and on live i586 images)
- update to 3.12.8
- drop merged patches

* Sun Jan 12 2014 tmb <tmb> 3.12.7-1.mga4
+ Revision: 566385
- add -stable network fixes (DaveM)
- ax88179_178a: Remove AX_MEDIUM_ALWAYS_ONE bit in AX_MEDIUM_STATUS_MODE
  register to avoid TX throttling
- Input: ALPS - add support for Dolphin devices
- Input: ALPS - add support for DualPoint device on Dell XT2
- Input: ALPS - change secondary devices name
- drop merged patch
- update to 3.12.7

* Thu Jan 09 2014 tmb <tmb> 3.12.6-5.mga4
+ Revision: 565949
- xhci: Set scatter-gather limit to avoid failed block writes
- xhci: Avoid infinite loop when sg urb requires too many trbs
- staging: r8712u: Set device type to wlan
- rtlwifi: rtl8192cu: Add new device ID: Sitecom WLA2100V2
- ath9k: Use correct channel for RX packets
- ath9k: Disable cross-band FCC
- sata_sis: add missing PM support
- drm/nouveau: return offset of allocated notifier
- drm/nouveau/bios: make jump conditional
- drm/nouveau/bios: fix offset calculation for BMPv1 bioses
- ahci: add PCI ID for Marvell 88SE9170 SATA controller
- update to 3.12.7-rc2

* Tue Jan 07 2014 tmb <tmb> 3.12.6-4.mga4
+ Revision: 565325
- cpufreq: Fix timer/workqueue corruption by protecting reading governor_enabled
- update to 3.12.7-rc1

* Fri Jan 03 2014 tmb <tmb> 3.12.6-3.mga4
+ Revision: 564316
- switch i586 squashfs to percpu multi-decompressor
- ACPI: Blacklist Win8 OSI for Asus VivoBook X202E (mga#7857)
- ACPI: Blacklist Win8 OSI for some HP laptop 2013 models
- drm/ttm: Fix accesses through vmas with only partial coverage
- drm/radeon: fix asic gfx values for scrapper asics
- drm/radeon: fix UVD 256MB check
- drm/radeon/dpm: disable ss on Cayman
- drm/radeon/dpm: Fix hwmon crash
- drm/radeon: add missing display tiling setup for oland
- drm/edid: add quirk for BPC in Samsung NP700G7A-S01PL notebook
- ACPI / PCI / hotplug: Avoid warning when _ADR not present
- add current -stable queue (49 fixes)
- ACPIPHP / radeon / nouveau: Fix VGA switcheroo problem related to hotplug
- nouveau_acpi: convert acpi_get_handle() to acpi_has_method()

* Sun Dec 29 2013 tmb <tmb> 3.12.6-2.mga4
+ Revision: 563031
- drm/i915: Fix erroneous dereference of batch_obj inside reset_status
- drm/i915: Use the correct GMCH_CTRL register for Sandybridge+
- drm/i915: Take modeset locks around intel_modeset_setup_hw_state()
- x86 idle: Repair large-server 50-watt idle-power regression
- ext4: fix deadlock when writing in ENOSPC conditions
- switch to single squashfs decompressor on i586
- switch to percpu squashfs multi-decompressor on x86_64
- drop parts of Q57 patch already applied upstream (Eugene A. Shatokhin / Rosalab)
- drop 3rdparty heci driver (obsoleted by in-kernel mei driver)
- drm/radeon: fix render backend setup for SI and CIK

* Fri Dec 20 2013 tmb <tmb> 3.12.6-1.mga4
+ Revision: 559211
- update to 3.12.6

* Sun Dec 15 2013 tmb <tmb> 3.12.5-1.mga4
+ Revision: 556853
- xfs: underflow bug in xfs_attrlist_by_handle() (CVE-2013-6382)
- xfs: add capability check to free eofblocks ioctl (CVE pending)
- kvm: rtc_status.dest_map out-of-bounds access (CVE-2013-4587)
- kvm: division by zero in apic_get_tmcct() (CVE-2013-6367)
- kvm: cross page vapic_addr access (CVE-2013-6368)
- kvm: BUG_ON() in apic_cluster_id() (CVE-2013-6376)
- update to 3.12.5

* Wed Dec 04 2013 tmb <tmb> 3.12.3-1.mga4
+ Revision: 555206
- ensure new stable btrfs-progs gets in the initrd when used
- Squashfs: fix failure to unlock pages on decompress error
- update to 3.12.3

* Sat Nov 30 2013 tmb <tmb> 3.12.2-1.mga4
+ Revision: 554298
- update ndiswrapper to 1.59
- add 33 fixes from -stable queue
- update to 3.12.2

* Thu Nov 21 2013 tmb <tmb> 3.12.1-1.mga4
+ Revision: 552194
- update squashfs multi-decompressor to revision being merged in 3.13
- update to 3.12.1

* Sun Nov 17 2013 tmb <tmb> 3.12.0-3.mga4
+ Revision: 551594
- ALSA: hda - hdmi: Fix reported channel map on common default layouts
- cxgb3: Fix length calculation in write_ofld_wr() on 32-bit architectures
- hyperv-fb: add pci stub
- ipv6: ip6_dst_check needs to check for expired dst_entries
- ipv6: reset dst.expires value when clearing expire flag
- net: flow_dissector: fail on evil iph->ihl
- net/mlx4_core: Fix call to __mlx4_unregister_mac
- net: sctp: do not trigger BUG_ON in sctp_cmd_delete_tcb
- tcp: do not rearm RTO when future data are sacked
- tcp: fix SYNACK RTT estimation in Fast Open
- tcp: gso: fix truesize tracking
- tcp: only take RTT from timestamps if new data is acked
- USB: add new zte 3g-dongle's pid to option.c
- virtio-net: correctly handle cpu hotplug notifier during resuming
- xen-netback: use jiffies_64 value to calculate credit timeout
- re-enable FB_SIMPLE

* Fri Nov 08 2013 tmb <tmb> 3.12.0-2.mga4
+ Revision: 550012
- make 'Fast TSC calibration failed' message a debug one to hide it during normal boot (mga#11532)
- pull in network fixes heading for -stable tree
- gpu/drm/i915: add disable_pch_pwm module option (Colin, bko #47941)
- disable FB_SIMPLE

* Mon Nov 04 2013 tmb <tmb> 3.12.0-1.mga4
+ Revision: 549323
- update to 3.12 final

* Sat Nov 02 2013 tmb <tmb> 3.12.0-0.rc7.2.mga4
+ Revision: 549135
- squashfs: Use multiple decompressors for handling parallel I/O
- xfrm: Fix null pointer dereference when decoding sessions
- update to latest 3.12-rc7-git

* Thu Oct 31 2013 tmb <tmb> 3.12.0-0.rc7.1.mga4
+ Revision: 548128
- update to 3.12-rc7 + current git

* Sat Oct 26 2013 tmb <tmb> 3.12.0-0.rc6.2.mga4
+ Revision: 547145
- update to current 3.12-rc6-git
- require dracut-034-4 for fixed /usr mounting

* Mon Oct 21 2013 tmb <tmb> 3.12.0-0.rc6.1.mga4
+ Revision: 540652
- update to 3.12-rc6

* Wed Oct 16 2013 tmb <tmb> 3.12.0-0.rc5.2.mga4
+ Revision: 501511
- build with new gcc & binutils
- update to latest git

* Mon Oct 14 2013 tmb <tmb> 3.12.0-0.rc5.1.mga4
+ Revision: 496717
- update to 3.12-rc5
- drop merged/obsolete patches
- fix ndiswrapper and mach64 drivers build with 3.12
- update aufs patch
- update overlayfs patches
- rediff IFWLOG patch
- update defconfigs
- update dkms conflicts

* Thu Oct 03 2013 tmb <tmb> 3.11.4-1.mga4
+ Revision: 490925
- update to 3.11.4
- drop merged patch

* Mon Sep 30 2013 tmb <tmb> 3.11.2-2.mga4
+ Revision: 489560
- require fixed dracut
- update to 3.11.3-rc1

* Fri Sep 27 2013 tmb <tmb> 3.11.2-1.mga4
+ Revision: 487565
- update dkms conflicts
- update to 3.11.2

* Wed Sep 25 2013 tmb <tmb> 3.11.1-1.mga4
+ Revision: 486267
- temporarily disable broken dothan-3 patch
- net: sync some IP headers with glibc
- update defconfigs
- update filelists
- rebase IBM BladeCenter HS20 hid quirk
- rebase shuttle-wmi driver
- rebase i915 patches for bko#59841
- update aufs for 3.11
- update overlayfs support
- drop merged patches
- update to 3.11.2-rc1
- disable GOLDFISH emulator support (mga #11062)

* Tue Sep 03 2013 tmb <tmb> 3.10.10-3.mga4
+ Revision: 474665
- [SCSI] pm80xx: fix Adaptec 71605H hang
- HID: Revert 'Revert 'HID: Fix logitech-dj: missing Unifying device issue''
- drm/i915: i915.disable_pch_pwm overrides PCH_PWM_ENABLE quirk,
            Allow disabling of eDP BPP overrides (coling, bko#59841)

* Fri Aug 30 2013 tmb <tmb> 3.10.10-2.mga4
+ Revision: 473322
- switch server kernel image compression back to GZIP so it works with
  Amazon EC2 and other older XEN setups
- Input: elantech - fix packet check for v3 and v4 hardware
- Input: wacom - add support for 0x300 and 0x301
- Input: xpad - add signature for Razer Onza Classic Edition
- drm/nouveau/mc: fix race condition between constructor and request_irq()
- jfs: fix readdir cookie incompatibility with NFSv4
- sunrpc: Fix memory corruption issue on 32-bit highmem systems
- workqueue: cond_resched() after processing each work item

* Thu Aug 29 2013 tmb <tmb> 3.10.10-1.mga4
+ Revision: 473059
- drop merged patches
- update to 3.10.10
- enable checkpoint/restore (requested by blino)

* Wed Aug 21 2013 tmb <tmb> 3.10.9-1.mga4
+ Revision: 469169
- mac80211: add a flag to indicate CCK support for HT clients
- ath9k: Enable PLL fix only for AR9340/AR9330
- net_sched: psched_ratecfg_precompute() improvements
- net_sched: restore "linklayer atm" handling
- dtop merged patches
- update to 3.10.9

* Sat Aug 17 2013 tmb <tmb> 3.10.7-1.mga4
+ Revision: 467151
- drm/radeon: fix WREG32_OR macro setting bits in a register
- drm/radeon/r7xx: fix copy paste typo in golden register setup
- add current stable queue (43 fixes)
- drop merged patches
- update to 3.10.7

* Mon Aug 12 2013 tmb <tmb> 3.10.6-1.mga4
+ Revision: 465860
- zram: allow request end to coincide with disksize
- drm/radeon: always program the MC on startup
- drm/radeon: fix halting UVD v2
- drm/radeon: only save UVD bo when we have open handles v2
- drop revert of "SCSI: sd: Update WRITE SAME heuristics" as the breakage
  is now fixed with "SCSI: Don't attempt to send extended INQUIRY command
  if skip_vpd_pages is set"
- add current -stable queue (44 fixes)
- update to 3.10.6 final

* Sun Aug 11 2013 tmb <tmb> 3.10.5-4.mga4
+ Revision: 465432
- update to 3.10.6-rc1
- drop merged patches

* Mon Aug 05 2013 tmb <tmb> 3.10.5-3.mga4
+ Revision: 464025
- atl1c: Fix misuse of netdev_alloc_skb in refilling rx ring
- iwlwifi: dvm: don't send BT_CONFIG on devices w/o Bluetooth
- iwlwifi: mvm: set SSID bits for passive channels
- disable FW_LOADER_USER_HELPER as udev is not doing any fw loading anymore
- fix and enable ndiswrapper with 3.10 series kernels (arch)
- drop 2 broken stable queue fixes

* Mon Aug 05 2013 tmb <tmb> 3.10.5-2.mga4
+ Revision: 463810
- add current stable queue (78 fixes)

* Sun Aug 04 2013 tmb <tmb> 3.10.5-1.mga4
+ Revision: 463583
- disable Initio 162x SATA support as its seriously broken
- drop merged patches
- update to 3.10.5

* Mon Jul 29 2013 tmb <tmb> 3.10.4-1.mga4
+ Revision: 460396
- revert: 'SCSI: sd: Update WRITE SAME heuristics' introduced upstream in
  3.10.3 as it breaks several usb3 connected disks.
- drop merged patches
- update to 3.10.4

* Fri Jul 26 2013 tmb <tmb> 3.10.3-1.mga4
+ Revision: 458375
- md: Remove recent change which allows devices to skip recovery
- md/raid5: fix interaction of 'replace' and 'recovery'
- md/raid10: remove use-after-free bug
- add current -stable queue fixes (44)
- drop merged patches
- update to 3.10.3

* Mon Jul 22 2013 tmb <tmb> 3.10.2-1.mga4
+ Revision: 457038
- suggest cpupower
- update to 3.10.2
- update conflicts on dkms drivers to get 3.10 for better upgrade support
- update conflicts on radeon-firmware to get all uvd and smc in initrd
- iwlwifi/mvm: enable 7000 series devices
- iwlwifi: pcie: don't read INTA register in ICT IRQ handler
- iwlwifi: make TX seqno validation more efficient
- Input: elantech - fix for newer hardware versions (v7)
- cpufreq/intel_pstate: Change to scale off of max P-state
- cpufreq: Revert commit 2f7021a to fix CPU hotplug regression

* Sun Jul 14 2013 tmb <tmb> 3.10.1-1.mga4
+ Revision: 454223
- disable broken ndiswrapper
- disable broken ppscsi driver
- disable parallell build for perf
- cpufreq: Revert commit a66b2e to fix cpufreq regression during suspend/resume
- make each kernel-*(-devel) suggest the matching -latest package
- suggest iw as we also suggest crda
- require new kernel-firmware
- conflict too old radeon-firmware to get the new UVD firmware in initrd
- update filelists
- re-add aufs support (mga#8314)
- update defconfigs
- drop merged patches
- rediff patches to apply cleanly
- update overlayfs patches
- update to 3.10.1
- add support for extended stable builds

* Fri Jun 28 2013 tmb <tmb> 3.9.8-1.mga4
+ Revision: 447730
- bcma: add support for BCM43142 (mga#9378, mga#10611)
- drop merged patches
- add current -stable queue (17 fixes)
- update to 3.9.8

* Fri Jun 21 2013 tmb <tmb> 3.9.7-1.mga4
+ Revision: 445339
- rtlwifi: rtl8192cu: Fix problem in connecting to WEP or WPA(1) networks
- ath9k_htc: Handle IDLE state transition properly
- update to 3.9.7

* Tue Jun 18 2013 tv <tv> 3.9.6-1.mga4
+ Revision: 444605
- new release

* Sun Jun 02 2013 tmb <tmb> 3.9.4-1.mga4
+ Revision: 434738
- fix ndiswrapper build with kernel-3.9
- add current stable queue fixes (82 fixes all over)
- fix -devel filelist
- fix up alx AR8161 breakage (mga #10079)
- conflict too old plymouth to make cleaner upgrades (mga #10128)
- dont package arc and metag arches
- enable CONFIG_FHANDLE
- update defconfigs
- drop merged patches
- BR: bc (as timeconst.pl has been replaced with a bc script)
- update to 3.9.4

* Tue May 14 2013 tmb <tmb> 3.8.13-1.mga3
+ Revision: 413188
- ACPICA: Fix possible buffer overflow during a field unit read operation
- ALSA: HDA: Fix Oops caused by dereference NULL pointer
- ARM: OMAP: RX-51: change probe order of touchscreen and panel SPI devices
- ASoC: wm8994: missing break in wm8994_aif3_hw_params()
- dm stripe: fix regression in stripe_width calculation
- dm table: fix write same support
- KVM: VMX: fix halt emulation while emulating invalid guest sate
- nfsd4: don't allow owner override on 4.1 CLAIM_FH opens
- nfsd: fix oops when legacy_recdir_name_error is passed a -ENOENT error
- shm: fix null pointer deref when userspace specifies invalid hugepage size
- revert 'drm/i915: set CPT FDI RX polarity bits based on VBT' as it
  triggers OOM on some Cougar Point systems (mga #10056)
- switch to 3.8.13 final (no change from -rc in 3.8.12-2)

* Fri May 10 2013 tmb <tmb> 3.8.12-2.mga3
+ Revision: 412824
- Input: Wacom: add support for DTH-2242 and 0x10d
- Input: ALPS: add Rushmore and Dolphin V1 support (mga #8033)
- Input: synaptics - fix 1->3 contact transition reporting
- Input: synaptics - initialize pointer emulation usage
- Input: Cypress/ps2 - fix trackpad found in Dell XPS12
- Input: Cypress APA - add support for smbus protocol
- add Cypress APA I2C Trackpad support
- update to 3.8.13-rc1
- drop merged patches

* Wed May 08 2013 tmb <tmb> 3.8.12-1.mga3
+ Revision: 412651
- drm/i915: Add no-lvds quirk for Fujitsu Esprimo Q900
- drm/i915: Fixup Oops in the pipe config computation
- drm/i915: set CPT FDI RX polarity bits based on VBT
- drm/cirrus: deal with bo reserve fail in dirty update path
- drm/cirrus: Correct register values for 16bpp
- carl9170: fix frame drop and WARN due to minstrel_ht change
- carl9170: remove fast channel change feature (unreliable)
- drm/i915: Fix detection of base of stolen memory
- drm/i915: Use MLC (l3$) for context objects
- drop merged patch
- update to 3.8.12
- update Atheros alx gigabit ethernet to latest upstream
- add support for Atheros Killer e2200 ethernet (#9979)

* Wed May 01 2013 tmb <tmb> 3.8.11-1.mga3
+ Revision: 411798
- tty: fix up atime/mtime mess, take three (Linus, upstream)
- drop merged patches
- update to 3.8.11
- dont make NLS_CODEPAGE_437 builtin

* Sat Apr 27 2013 tmb <tmb> 3.8.10-1.mga3
+ Revision: 411320
- block: fix max discard sectors limit
- drm/radeon: add some new SI PCI ids
- drm/radeon: add new richland pci ids
- aio: fix possible invalid memory access when DEBUG is enabled
- TTY: do not update atime/mtime on read/write (CVE-2013-0160)
- TTY: fix atime/mtime regression
- update to 3.8.10
- drop merged patches
- update to 3.8.9

* Mon Apr 22 2013 tmb <tmb> 3.8.8-3.mga3
+ Revision: 410885
- ssb: implement spurious tone avoidance (fixes b43 regression)
- more stable queue fixes (arm, ath9k, sched)

* Sat Apr 20 2013 tmb <tmb> 3.8.8-2.mga3
+ Revision: 410585
- kvm: fix cve-2013-1796, cve-2013-1797, cve-2013-1798
- make sure to get latest btrfs-progs in initrd if in use
- add upstream -stable queue (11 fixes)
- intel_idle: add Haswell support
- tg3: Add 57766 device support
- sort posttrans so build and source symlinks are added before calling dkms_autoinstaller
- change kernel post scripts to posttrans (#9536)

* Wed Apr 17 2013 tmb <tmb> 3.8.8-1.mga3
+ Revision: 410270
- drop removal of check in disable-aspm-link as upstream breakage has been reverted
- update to 3.8.8
- bump requires on bootloader-utils, dracut, kmod, sysfsutils, kernel-firmware
- set DEFAULT_NLS to utf8 (#9722)
- conflict too old drakxtools-backend to avoid adding bogus root=/dev/ (#9536)
- enable CONFIG_RELOCATABLE on i586 too (needed for UEFI boot)
- conflict too old lvm2 rules to make upgrades work (tv, mga #9356)

* Sat Apr 13 2013 tmb <tmb> 3.8.7-1.mga3
+ Revision: 409914
- ALSA: usb: Work around CM6631 sample rate change bug (upstream)
- drm/radeon: don't use get_engine_clock() on APUs (mga #8077, fdo #62493)
- add current -stable queue fixes (16 fixes)
- drop merged patches
- update to 3.8.7

  + rtp <rtp>
    - drop uimage support. It's not compatible with dtb usage
    - build dtbs on arm
    - fix usage of udelay() for a msecs delay
    - put zsmalloc as built-in on arm to workaround build failure

* Tue Apr 09 2013 tmb <tmb> 3.8.6-2.mga3
+ Revision: 409204
- make EFI_VARS builtin
- ata_piix: Fix DVD not dectected at some Haswell platforms
- libata: fix DMA to stack in reading devslp_timing parameters
- libata: Set max sector to 65535 for Slimtype DVD A DS8A8SH drive
- libata: Use integer return value for atapi_command_packet_set
- md: raid1,10: Handle REQ_WRITE_SAME flag in write bios
  (fixes raid10 crash on mptsas)
- drop requires on carl9170-firmware as its merged in kernel-firmware

* Sun Apr 07 2013 tmb <tmb> 3.8.6-1.mga3
+ Revision: 408736
- add -stable queue fixes (20 fixes)
- update to 3.8.6

* Sat Mar 30 2013 tmb <tmb> 3.8.5-1.mga3
+ Revision: 406608
- disable efivars as a storage backend for pstore by default
  as it can brick some computers
- SUNRPC: Add barriers to ensure read ordering in rpc_wake_up_task_queue_locked
- update to 3.8.5
- drop merged patches

* Mon Mar 18 2013 tmb <tmb> 3.8.3-2.mga3
+ Revision: 403953
- enable XEN_BALLOON_MEMORY_HOTPLUG on server kernels (#9372)
- more -stable queue fixes
- revert 2 drm/i915 patches introduced in 3.8.3 as they break more than they fix
- PCI: Remove not needed check in disable aspm link (should fix ath5k problems)
- more fixes from -stable queue

* Fri Mar 15 2013 tmb <tmb> 3.8.3-1.mga3
+ Revision: 403296
- net: ax88179_178a: add ASIX AX88179_178A USB 3.0/2.0 to gigabit ethernet
  adapter driver
- net: asix: init ASIX AX88772B MAC from EEPROM
- net: asix: handle packets crossing URB boundaries
- usb/net/asix_devices: Add USBNET HG20F9 ethernet dongle
  (requested by Colin)
- atl1c: restore buffer state
- add current -stable queue fixes (28)
- update to 3.8.3

* Sat Mar 02 2013 tmb <tmb> 3.8.1-1.mga3
+ Revision: 401081
- drm/i915: Fix Haswell/CRW PCI IDs
- update to 3.8.2-rc1
- drop merged patches

* Thu Feb 28 2013 tmb <tmb> 3.8.0-3.mga3
+ Revision: 400575
- sync up with current -stable queue (154 additional fixes all over)
- require fixed dracut

* Fri Feb 22 2013 tmb <tmb> 3.8.0-2.mga3
+ Revision: 399983
- disable 'mac80211: improve latency and throughput while software scanning' for now
- perf hists: Fix period symbol_conf.field_sep display
- perf tools: Fix build with bison 2.3 and older
- x86-32, mm: Remove reference to alloc_remap()
- x86-32, mm: Remove reference to resume_map_numa_kva()
- x86-32, mm: Rip out x86_32 NUMA remapping code
- x86, efi: Make noefi really disable EFI runtime serivces
- btrfs: access superblock via pagecache in scan_one_device
- btrfs: fix crash in log replay with qgroups enabled
- update ndiswrapper to 1.58

* Tue Feb 19 2013 tmb <tmb> 3.8.0-1.mga3
+ Revision: 399296
- update to 3.8 final
- drop merged patches
- add Intel Wellsburg PCH support to ahci, ata_piix, i2c, lpc, sound

* Fri Feb 08 2013 tmb <tmb> 3.8.0-0.rc7.1.mga3
+ Revision: 397185
- r8169: revert: 'enable ALDPS for power saving' as it breaks some hw (#8622)
- r8169: revert: 'enable internal ASPM and clock request settings' as it
  increases boot time
- update to 3.8-rc7

* Fri Feb 08 2013 tmb <tmb> 3.8.0-0.rc6.2.mga3
+ Revision: 397028
- drm/ttm: fix fence locking in ttm_buffer_object_transfer
- mac80211: improve latency and throughput while software scanning
- brcmsmac: double time for timeout
- ath9k: fix DMA idle but MAC is still stuck processing events
- rtlwifi: fix scheduling while atomic bug
- add support for Cypress PS2 Trackpads
- update to rc6-git as of: Wed Feb 6 12:11:10 2013 -0500

* Wed Feb 06 2013 tmb <tmb> 3.8.0-0.rc6.1.mga3
+ Revision: 394927
- disable perf build as it breaks on BS
- add more updates from upstream git
- add support for booting without initrd
  * https://wiki.mageia.org/en/Feature:BootSansRamdisk
  * works on ahci controllers, with ext4 and btrfs filesystems
  * theese options are now builtin: CONFIG_SCSI_MOD, CONFIG_SCSI,
    CONFIG_BLK_DEV_SD, CONFIG_ATA, CONFIG_SATA_AHCI, CONFIG_EXT4_FS,
    CONFIG_JBD2, CONFIG_BTRFS_FS, CONFIG_CRYPTO_CRC32C, CONFIG_CRC16,
    CONFIG_CRC_T10DIF, CONFIG_LIBCRC32C, CONFIG_ZLIB_DEFLATE
- update to 3.8-rc6-git
- fix perf build

* Sun Jan 27 2013 tmb <tmb> 3.8.0-0.rc5.1.mga3
+ Revision: 392632
- update to 3.8-rc5

* Fri Jan 18 2013 tmb <tmb> 3.8.0-0.rc4.1.mga3
+ Revision: 389476
- update to 3.8-rc4

* Wed Jan 16 2013 tmb <tmb> 3.8.0-0.rc3.2.mga3
+ Revision: 388788
- iwlwifi: audit single frames from AGG queue in RS
- drop __devinit/exit from heci, ndiswrapper, alx, shuttle-wmi
- update to 3.8-rc3-git as of 2013-01-16
- drop build, source symlinking of source package to kernel tree as it
  makes dkms build unusable modules
- rename -debug packages to -debuginfo
- specfile cleanups
- add more dkms conflicts
- conflict dkms packages that does not support kernel-3.8 to help upgrade ordering

* Thu Jan 10 2013 tmb <tmb> 3.8.0-0.rc3.1.mga3
+ Revision: 344645
- disable broken perf build for now
- update defconfigs
- rediff patches to apply cleanly
- drop merged zram patches
- update to 3.8-rc3
- update to 3.8-rc2-git as of 2013-01-04

* Tue Dec 18 2012 tmb <tmb> 3.7.1-1.mga3
+ Revision: 332459
- sync defconfigs
- update to 3.7.1
- fix zram oops (upstream, reported by wally)

* Tue Dec 11 2012 tmb <tmb> 3.7.0-1.mga3
+ Revision: 329575
- drop merged patch
- update to 3.7.0 final

* Thu Dec 06 2012 tmb <tmb> 3.7.0-0.rc8.1.mga3
+ Revision: 327546
- add perf bash_completion
- more filelist updates
- add 3.7 buildfixes for alx, IFWLOG, mach64, ndiswrapper
- pull in more upstream git fixes
- rediff disable-mrproper patch
- update to current rc8+ git
- update filelists
- update defconfigs
- restore patch preferring ata over ide drivers
- rediff patches to apply properly
- drop compress modules at install time patch
  (obsolete as we compress them at rpm build time)
- drop netbook kernel as it has no real advantage over desktop
  kernel anymore
- obsolete kernel-netbook*-latest kernel with the matching
  desktop kernels to keep upgrade path
- drop merged patches
- update to 3.7-rc8

* Wed Oct 31 2012 tmb <tmb> 3.6.5-1.mga3
+ Revision: 311802
- updates from stable queue:
  blkcg: Fix use-after-free of q->root_blkg and q->root_rl.blkg
  ceph: avoid 32-bit page index overflow
  ceph: fix dentry reference leak in encode_fh()
  ceph: Fix oops when handling mdsmap that decreases max_mds
  libceph: avoid NULL kref_put when osd reset races with alloc_msg
  libceph: check for invalid mapping
  floppy: don't call alloc_ordered_workqueue inside the alloc_disk loop
  floppy: do put_disk on current dr if blk_init_queue fails
  floppy: properly handle failure on add_disk loop
  gpio-timberdale: fix a potential wrapping issue
  gpiolib: Don't return -EPROBE_DEFER to sysfs, or for invalid gpios
  md/raid1: Fix assembling of arrays containing Replacements
  rbd: reset BACKOFF if unable to re-queue
- replace 'ext4: revert jbd2: don't write superblock when if its empty'
  with upstream fix: 'ext4: fix unjournaled inode bitmap modification'
  (wich properly fixes the possible data corruption bug)
- drop merged patches
- update to 3.6.5

* Sun Oct 28 2012 tmb <tmb> 3.6.4-1.mga3
+ Revision: 311107
- ext4: revert 'jbd2: don't write superblock when if its empty' (fixes possible data corruption)
- cpufreq / powernow-k8: Remove usage of smp_processor_id() in preemptible code
- add current stable queue fixes (71 fixes all over)
- update to 3.6.4

* Sun Oct 21 2012 tmb <tmb> 3.6.3-1.mga3
+ Revision: 309009
- drop merged patches
- update to 3.6.3
- add Atheros AR8161/8165 PCI-E Gigabit support (#7853)

* Wed Oct 17 2012 tmb <tmb> 3.6.2-1.mga3
+ Revision: 307752
- add mach64 and ipt_IFWLOG buildfixes for kernel-3.6
- sync in current stable queue (53 fixes)
- update defconfigs
- sync overlayfs support with opensuse
- disable acpi-video-add-blacklist-to-use-vendor-driver.patch, needs to be rewritten
- drop tools-perf-fix-strerror_r-usage.patch (merged)
- rediff patches:
  char-agp-intel-new-Q57-id.patch
  net-netfilter-psd-mdv.patch
  pci-pciprobe-CardBusNo.patch
- add include/ras/ to -devel and -source filelists
- update to 3.6.2
- move -doc to Documentation group

* Sun Sep 30 2012 tmb <tmb> 3.5.5-0.rc1.1.mga3
+ Revision: 300733
- update to 3.5.5-rc1 (262 fixes all over)

* Sat Sep 15 2012 tmb <tmb> 3.5.4-1.mga3
+ Revision: 294085
- drop merged patches
- update to 3.5.4

  + tv <tv>
    - cpupower obsoletes cpufreq cpufrequtils
    - set default policy as 'ondemand' (like cpufreq)

* Tue Sep 11 2012 tmb <tmb> 3.5.3-3.mga3
+ Revision: 292275
- ext3: Fix fdatasync() for files with only i_size changes (mga #7343)
- udf: Fix data corruption for files in ICB
- update defconfigs for overlayfs
- add overlayfs support (from ubuntu)
- disable broken unionfs
- sync with -stable queue (30 added fixes)

* Thu Aug 30 2012 tmb <tmb> 3.5.3-2.mga3
+ Revision: 285684
- pull in stable queue fixes (55 fixes all over)

* Sun Aug 26 2012 tmb <tmb> 3.5.3-1.mga3
+ Revision: 284238
- update to 3.5.3

* Thu Aug 16 2012 tmb <tmb> 3.5.2-1.mga3
+ Revision: 281575
- update to 3.5.2

* Sat Aug 11 2012 tmb <tmb> 3.5.1-1.mga3
+ Revision: 280494
- adapt unionfs for FD and BITS changes in 3.5.1
- enable CLEANCACHE, FRONTSWAP and ZCACHE (mga #6946)
- update to 3.5.1

* Sat Jul 28 2012 tmb <tmb> 3.5.0-1.mga3
+ Revision: 275103
- fix perf build with glibc-2.16
- fix unionfs build with 3.5 series kernels
- rediff mrproper patch
- update defconfigs
- drop merged patches
- rediff unionfs patch
- add include/memory/ to -devel and -source filelists
- update to 3.5

* Fri Jul 20 2012 tmb <tmb> 3.4.6-1.mga3
+ Revision: 272883
- add fixes from current stable queue (13 fixes)
- update to 3.4.6
- drop merged patch

* Wed Jul 18 2012 tmb <tmb> 3.4.5-1.mga3
+ Revision: 272320
- drop merged patches
- update to 3.4.5
- scsi: Silence unnecessary warnings about ioctl to partition (requested by colin)

* Sun Jul 01 2012 tmb <tmb> 3.4.4-2.mga3
+ Revision: 266170
- block: fix infinite loop in __getblk_slow
- enable EFI_STUB support (#6598)
- cifs: fix parsing of password mount option (requested by blino)
- ARM: Orion: Fix Virtual/Physical mixup with watchdog
- ARM: tegra: make tegra_cpu_reset_handler_enable() __init

* Wed Jun 27 2012 tmb <tmb> 3.4.4-1.mga3
+ Revision: 264235
- Tools: hv: verify origin of netlink connector message (CVE-2012-2669)
- drop merged patches
- update to 3.4.4

* Wed Jun 20 2012 tmb <tmb> 3.4.3-1.mga3
+ Revision: 262305
- pull in current -stable queue (61 fixes all over)
- rediff patch for added Q57 agp id
- drop merged ext4 uninit_bg fix
- update to 3.4.3

* Sat Jun 09 2012 tmb <tmb> 3.4.2-1.mga3
+ Revision: 258990
- ext4: fix the free blocks calculation for ext3 file systems w/ uninit_bg
- drop merged patches
- update to 3.4.2
- BR kmod instead of module-init-tools

* Tue Jun 05 2012 tmb <tmb> 3.4.1-1.mga3
+ Revision: 255531
- add patches from stable queue (66 fixes all over)
- require kmod instead of module-init-tools
- re-enable pwersaving by default on rt2800usb
- disable changing ata/ide link order
- update to 3.4.1 final

* Mon May 28 2012 tmb <tmb> 3.4.1-0.rc1.1.mga3
+ Revision: 247815
- BR bison for kernel utils
- BR flex for kernel utils
- BR pkgconfig(gtk+-2.0) for kernel tools
- disable acpi dsdt and events patches
- update to 3.4.1-rc1
  * drop merged patches
  * rediff IFWLOG, psd, unionfs shuttle-wmi and arm-udelay-fix patches
- add buildfix for unionfs and kernel-3.4
- add buildfix for radio-rttrack
- update defconfigs
- update filelists

* Thu May 17 2012 tmb <tmb> 3.3.6-2.mga2
+ Revision: 235853
- net/e1000: Prevent reset task killing itself (fixes deadlock)
- pull in fixes from stable queue:
  * ALSA: echoaudio: Remove incorrect part of assertion
  * ALSA: HDA: Lessen CPU usage when waiting for chip to respond
  * ALSA: hda/realtek - Add missing CD-input pin for MSI-7350 mobo
  * ALSA: hda/idt - Fix power-map for speaker-pins with some HP laptops
  * usbnet: fix skb traversing races during unlink(v2)
  * namespaces, pid_ns: fix leakage on fork() failure
- ipw2x00: add support for nl80211 clients like Network Manager (#5720)
- disable APM_CPU_IDLE as it causes some hw to hang on boot

* Sat May 12 2012 tmb <tmb> 3.3.6-1.mga2
+ Revision: 235512
- switch server kernels back to SLAB allocator as it performs better on
  bigger server hardware and workloads
- disable memory cgroups on desktop(586) and netbook kernels as it has
  unwanted overhead (server kernels still have it enabled)
- sync defconfigs for 3.3.6
- drop merged patches
- update to 3.3.6

* Thu May 10 2012 tmb <tmb> 3.3.5-1.mga2
+ Revision: 235140
- obsolete dkms-psb (replaced by in-kernel gma500_gfx)
- add current stable queue fixes:
  ARM: 7410/1: Add extra clobber registers for assembly in kernel_execve
  ARM: 7411/1: audit: fix treatment of saved ip register during syscall tracing
  ARM: 7412/1: audit: use only AUDIT_ARCH_ARM regardless of endianness
  ARM: 7414/1: SMP: prevent use of the console when using idmap_pgd
  ARM: OMAP: Revert "ARM: OMAP: ctrl: Fix CONTROL_DSIPHY register fields"
  ARM: orion5x: Fix GPIO enable bits for MPP9
  asix: Fix tx transfer padding for full-speed USB
  asm-generic: Use __BITS_PER_LONG in statfs.h
  ASoC: core: check of_property_count_strings failure
  ASoC: tlv312aic23: unbreak resume
  drm/i915: disable sdvo hotplug on i945g/gm
  drm/i915: Do no set Stencil Cache eviction LRA w/a on gen7+
  drm/i915: enable dip before writing data on gen4
  e1000: fix vlan processing regression
  Fix __read_seqcount_begin() to use ACCESS_ONCE for sequence value read
  fs/cifs: fix parsing of dfs referrals
  netem: fix possible skb leak
  net: Add memory barriers to prevent possible race in byte queue limits
  net: Fix issue with netdev_tx_reset_queue not resetting queue from XOFF state
  net: In unregister_netdevice_notifier unregister the netdevices
  net: l2tp: unlock socket lock before returning from l2tp_ip_sendmsg
  percpu, x86: don't use PMD_SIZE as embedded atom_size on 32bit
  regulator: Fix the logic to ensure new voltage setting in valid range
  sky2: fix receive length error in mixed non-VLAN/VLAN traffic
  sky2: propogate rx hash when packet is copied
  smsc95xx: mark link down on startup and let PHY interrupt deal with carrier changes
  sungem: Fix WakeOnLan
  tcp: change tcp_adv_win_scale and tcp_rmem[2]
  tcp: fix infinite cwnd in tcp_complete_cwr()
  tg3: Avoid panic from reserved statblk field access
  x86, relocs: Remove an unused variable
  xen/pci: don't use PCI BIOS service for configuration space accesses
  xen/pte: Fix crashes when trying to see non-existent PGD/PMD/PUD/PTEs
- drop merged samsung-laptop patches
- drop merged patches
- update to 3.3.5
- dell-laptop: Terminate quirks list properly (mga #5724)

* Sat Apr 28 2012 tmb <tmb> 3.3.4-1.mga2
+ Revision: 233744
- ata_piix: detect IDE mode SATA for Intel DH89xxCC
- ahci detect Marvell 88SE9172 SATA controller
- iwlwifi: use 6000G2B for 6030 device series
- iwlwifi: fix hardware queue programming
- cpupower: Require rpm-helper >= 0.24.8-1 for systemd support
- drop perf revert as it's now fixed upstream
- update to 3.3.4
- require dracut >= 017-9

* Mon Apr 23 2012 tmb <tmb> 3.3.3-1.mga2
+ Revision: 232856
- revert: "perf hists: Catch and handle out-of-date hist entry maps"
  added in stable 3.3.3 as it breaks perf build
- ath5k: do not stop queues for full calibration
- ath5k: do not re-run AGC calibration periodically
- iwlwifi: use correct released ucode version
- disable floppy autoloading as it makes some systems hang (mga #4696)
- drop merged patches
- update to 3.3.3

* Wed Apr 04 2012 tmb <tmb> 3.3.1-2.mga2
+ Revision: 228344
- ACPICA: Fix regression in FADT revision checks
- revert 'gpu/nouveau/bios: Fix tracking of BIOS image data' as it breaks some hw
- clean dkms tree on kernel uninstall
- clean -devel tree on uninstall
- drm/nouveau: create m2mf for nvd9 too
- drm/nouveau: inform userspace of relaxed kernel subchannel requirements
- drm/nouveau: select POWER_SUPPLY
- drm/nouveau: Fix crash when pci_ram_rom() returns a size of 0
- drm/nouveau/bios: Fix tracking of BIOS image data
- drm/radeon/kms: fix fans after resume
- drm/radeon: Don't dereference possibly-NULL pointer
- revert: 'x86/ioapic: Add register level checks to detect bogus io-apic
  entries' as it breaks xen
- revert: 'ath9k: fix going to full-sleep on PS idle' as it breaks atleast 9285

* Tue Apr 03 2012 tmb <tmb> 3.3.1-1.mga2
+ Revision: 228038
- drm/i915: add Ivy Bridge GT2 Server entries
- only server kernel provides drbd-api
- make sure dracut is always installed
- update defconfigs
- drm/nouveau: fix thinko causing init to fail on cards without accel
- drm/nouveau: default to 8bpc for non-LVDS panels if EDID isn't useful
- drm/nouveau/i2c: fix thinko/regression on really old chipsets
- drop merged patches
- resync radeon backport with 3.4-rc1
- update to 3.3.1
- replace kernel-tools package with separate perf and cpupower packages

* Sat Mar 24 2012 tmb <tmb> 3.3.0-2.mga2
+ Revision: 226128
- disable ath9k fix for mga #144 to verify if its still needed
- ata: add ide/ahci/raid mode support for Intel Lynx Point chipset
- nouveau: backport Kepler (GTX6xx) support
- radeon: backport support for Southern Islands (HD7xxx) GPUs and Trinity APUs
- add upstream drm changes to support gpu driver backports
- ata: prefer ata drivers over ide drivers when both are built (Anssi)

* Mon Mar 19 2012 tmb <tmb> 3.3.0-1.mga2
+ Revision: 224352
- disable framebuffer logo to try and reduce screen flickering on boot
- media/tda10071: correct delivery system to DVB-S/S2
- media: fix initialization on Hauppauge WinTV Nova HD-S2 and similar hardware
- update defconfigs
- update to 3.3 final

* Sat Mar 10 2012 tmb <tmb> 3.3.0-0.rc7.1.mga2
+ Revision: 222555
- update to 3.3-rc7
- re-enable some more nics that got disabled by mistake
- re-enable MACVLAN and VETH (#4833)

* Mon Mar 05 2012 tmb <tmb> 3.3.0-0.rc6.1.mga2
+ Revision: 219069
- remove c6x arch from source tarball
- fix mach64 build with 3.3 series
- update defconfigs
- update unionfs to 2.5.11
- fix ndiswrapper build with 3.3 series kernels
- update to ndiswrapper 1.57 final
- update filelists
- rediff patches to apply cleanly
- drop merged patches
- update to 3.3-rc6

* Sat Mar 03 2012 tmb <tmb> 3.2.9-2.mga2
+ Revision: 217219
- rebuild with new gcc
- sync in current -stable queue (14 fixes)

* Thu Mar 01 2012 tmb <tmb> 3.2.9-1.mga2
+ Revision: 216396
- obsolete dkms-lzma
- require dracut >= 017-1
- add another needed fix for r8172u wireless driver in staging (#4491)
- drop merged fixes
- update to 3.2.9

* Sat Feb 25 2012 tmb <tmb> 3.2.7-1.mga2
+ Revision: 214713
- PCI: workaround hard-wired bus number
- mac80211: Fix a rwlock bad magic bug
- fix nonworking r8172u wireless driver in staging (#4491)
- enable PRINTK_TIME by default to help debugging boot delays
- drop merged patches
- update to 3.2.7

* Thu Feb 16 2012 tmb <tmb> 3.2.6-3.mga2
+ Revision: 209763
- rebuild for missing kmod provides
- require dracut >= 016-1 for more needed fixes
- fix modules.description generation with .xz modules

* Tue Feb 14 2012 tmb <tmb> 3.2.6-2.mga2
+ Revision: 208929
- require dracut >= 015-2 to get the latest fixes
- pull in current -stable queue (20 fixes)
- add post and preun service calls for cpupower in kernel-tools package
- require dracut >= 015-1 for support of xz compressed modules
- compress modules with xz
- update to 3.2.6 final
- compress symvers files in /boot with xz

* Sun Feb 12 2012 tmb <tmb> 3.2.6-0.rc1.1.mga2
+ Revision: 207659
- ath9k: stop on rates with idx -1 in ath9k rate control's .tx_status
- ath9k_hw: fix a RTS/CTS timeout regression
- ath9k: fix a WEP crypto related regression (# 4309)
- update to 3.2.6-rc1
- enable PPS_CLIENT_LDISC (mga #4221)

* Mon Feb 06 2012 tmb <tmb> 3.2.5-1.mga2
+ Revision: 205596
- pull in carl9170-firmware too as it's not in upstream kernel-firmware yet (#2386)
- update to 3.2.5
  * drop merged ASPM rework patch
- correct requires: module-init-tools >= 3.16-14 for xz support

* Thu Jan 26 2012 tmb <tmb> 3.2.2-1.mga2
+ Revision: 201806
- drop merged patches
- update to 3.2.2 (CVE-2012-0056)

* Fri Jan 20 2012 tmb <tmb> 3.2.1-2.mga2
+ Revision: 198861
- BR module-init-tools >= 3.6-14 for xz support
- add support for compressing modules with xz (disabled until dracut gets support)
- compress desktop* and server kernels with XZ (even xen supports it since v4.0)
- enable xen support on x86_64 kernel-desktop
- require module-init-tools >= 3.6-14 for xz support
- require dracut instead of mkinitrd

* Sun Jan 15 2012 tmb <tmb> 3.2.1-1.mga2
+ Revision: 196371
- fix groups on on kernel-utils(-devel)
- add BR docbook-style-xsl
- add patches from -stable queue (51 fixes all over the kernel)
- add kernel-tools(-devel) packages providing perf and cpupower tools (#3413)
- drop kernel-xen-pvops flavour as kernel-server provides all that is needed
  * kernel-server-latest now obsoletes kernel-xen-pvops-latest
  * kernel-server-devel-latest now obsoletes kernel-xen-pvops-devel-latest
- sync xen config with fedora
- update to 3.2.1

* Thu Jan 05 2012 tmb <tmb> 3.2.0-1.mga2
+ Revision: 191540
- update to 3.2 final
- require newest kernel-firmware
- obsolete dkms-r8192se as it is merged upstream
- upstream tarball is now compressed with xz

* Wed Dec 28 2011 tmb <tmb> 3.2.0-0.rc7.2.mga2
+ Revision: 188492
- update to latest upstream git including: drm/i915: Disable RC6 on
  Sandybridge by default (371de6e4e0042adf4f9b54c414154f57414ddd37)
- disable SQUASHFS_4K_DEVBLK_SIZE as it breaks livecd builds

* Sun Dec 25 2011 tmb <tmb> 3.2.0-0.rc7.1.mga2
+ Revision: 187363
- ndiswrapper: fix build with 3.2 series kernels
- unionfs: convert ->i_nlink usage to set_nlink()
- drm/mach64: module.h must now be included directly
- update defconfigs
- add fixes for radeon and vmwgfx from upstream git headed for 3.2 final
- update filelists
- rebase patches to apply cleanly
- drop merged patches
- update to 3.2-rc7
- make sure -devel rpm is installed before triggering dkms rebuild

* Sat Dec 24 2011 tmb <tmb> 3.1.6-2.mga2
+ Revision: 187103
- update netbook summary and description too regarding memory usage
- sync with current stable queue (38 fixes to all over the kernel)

* Thu Dec 22 2011 tmb <tmb> 3.1.6-1.mga2
+ Revision: 185703
- update to 3.1.6 final
- enable ISDN in netbook config (#3367)
- switch transparent hugepages from on by default to madvise (only enabled
  for apps that requests it), as it fixes desktop freeze when accessing
  slow media such as usb (thanks to fbui/mdv mail on @cooker ml).
- update desktop(586) summaries and descriptions to point out that only
  3-3.5GB RAM is detected on 32bit, and that server kernel is needed to
  fully support 4GB or more
- drop defattr and buildroot
- trigger dkms build in posttrans so modules get built at kernel install
  instead of at boot (speeds up boot time with new kernel)

* Fri Dec 16 2011 tmb <tmb> 3.1.6-0.rc1.1.mga2
+ Revision: 182783
- bump requires on kernel-firmware
- drop merged drm and xfs patches
- update to 3.1.6-rc1

* Mon Dec 05 2011 tmb <tmb> 3.1.4-2.mga2
+ Revision: 176941
- rebuild with gcc-4.6.2

  + blino <blino>
    - IFWLOG: fix return value of checkentry (not properly modified in 2.6.35+ patch, #3594)

* Tue Nov 29 2011 tmb <tmb> 3.1.4-1.mga2
+ Revision: 174077
- update to 3.1.4
  * reverts usb patch that broke isochronous devices
    (i.e. webcam, audio, or other streaming devices)

* Sun Nov 27 2011 tmb <tmb> 3.1.3-1.mga2
+ Revision: 172918
- xfs fixes from upstream:
  * don't serialise direct IO reads on page cache checks
    (fixes performance regression introduced in 2.6.38)
  * avoid direct I/O write vs buffered I/O race
  * return -EIO when xfs_vn_getattr() failed
  * fix buffer flushing during unmount
  * fix possible memory corruption in xfs_readlink
  * use doalloc flag in xfs_qm_dqattach_one()
- drm fixes from stable queue:
  * fix integer overflow in drm_mode_dirtyfb_ioctl()
  * radeon/kms: fix up gpio i2c mask bits for r4xx for real
  * i915: Ivybridge still has fences
  * i915: Turn on a required 3D clock gating bit on Sandybridge
  * i915: Turn on another required clock gating bit on Sandybridge
- update to 3.1.3

* Sun Nov 20 2011 tmb <tmb> 3.1.2-0.rc1.1.mga2
+ Revision: 170001
- update to 3.1.2-rc1
- pci: rework ASPM disable code
- drm/i915: Fix inconsistent backlight level during disabled
- update to 3.1.1 final

* Thu Nov 10 2011 tmb <tmb> 3.1.1-0.rc1.1.mga2
+ Revision: 166212
- update to 3.1.1-rc1
  * rediff unionfs patch
  * drop merged patches
  * update defconfigs

* Tue Nov 01 2011 tmb <tmb> 3.1.0-2.mga2
+ Revision: 161124
- md/raid10: Fix bug when activating a hot-spare.
- md/raid5: fix bug that could result in reads from a failed device.
- enable PM_RUNTIME and USB_SUSPEND

* Mon Oct 24 2011 tmb <tmb> 3.1.0-1.mga2
+ Revision: 157691
- update to 3.1 final

* Tue Oct 18 2011 tmb <tmb> 3.1.0-0.rc10.1.mga2
+ Revision: 156037
- update to 3.1-rc10
- drop merged patches
- re-enable usblp as it is needed by both usb-pp adapters and some printers (mga #2240, #2264)
  (cups is patched to work with both usblp and libusb)

* Thu Oct 06 2011 tmb <tmb> 3.1.0-0.rc9.1.mga2
+ Revision: 152256
- fix ndiswrapper Makefile
- remove openrisc arch
- more defconfig updates
- SCSI: libsas: fix panic when single phy is disabled on a wide port
  SCSI: qla2xxx: Fix crash in qla2x00_abort_all_cmds() on unload
- Input: wacom - revert 'Cintiq 21UX2 does not have menu strips'
- update ndiswrapper to 1.57-rc1 and drop merged patches
- update unionfs to 2.5.10
- update defconfigs
- drop merged: media-video-uvc-fix-init-hang.patch
- drop merged patch:
  scripts-headers_install-fix-__packed-in-exported-kernel-headers.patch
- drop patch: sound-alsa-hda_intel-prealloc-4mb-dmabuffer.patch
  (it's replaced by the upstream SND_HDA_PREALLOC_SIZE config option)
- rediff patches to apply cleanly
- rediff unionfs patch
- update to 3.1-rc9

* Mon Oct 03 2011 tmb <tmb> 3.0.6-1.mga2
+ Revision: 151408
- fix boot hang on uvc webcam init (mga #2425)
- update to 3.0.6
- ndiswrapper: add IoUnregisterPlugPlayNotification symbol (mga #2162)

* Mon Aug 29 2011 tmb <tmb> 3.0.4-1.mga2
+ Revision: 136300
- update to 3.0.4
- headers_install: fix __packed in exported kernel headers
- btrfs: btrfs_calc_avail_data_space: cope with no read/write devices
- update to 3.0.3
- drop merged: net-wireless-iwlagn-5000-do-not-support-idle-mode.patch
- update to 3.0.2-rc1
- update to 3.0.1 final
- enable RT33XX/RT35XX pci/usb support
- iwlagn: 5000 do not support idle mode
- drop debug-latest rpms as they are not really used
- rename debug rpms so the name ends with -debug like all other debug packages
- update to 3.0.1-rc1
- build with -s(ilent) so only warnings and errors gets logged
- fix build with -stable -rc patches
- drop obsolete conflicts/obsoletes
- remove powerpc and sparc support (already disabled)
- convert -source rpm to noarch
- release 3.0 final
- samsung-laptop: add support for NC110, NC210, R700 and X520
- samsung-laptop: fix detection of N150/N210/N220 models (mga #2175)
- disable SOUND_OSS_CORE_PRECLAIM to allow osspd to work (request by Coling Guthrie)
- prepare for 3.0 final
- drop uclevel define as its unused
- drop kstable defines as sublevel will be used for stable patches

* Sun Jul 17 2011 tmb <tmb> 3.0.0-0.rc7.5.1.mga2
+ Revision: 125370
- update to 3.0-rc7-git5 (fixes 32bit sched race/hang and a possible rcu hang/crash)

* Fri Jul 15 2011 tmb <tmb> 3.0.0-0.rc7.2.1.mga2
+ Revision: 124486
- update filelists
- rediff patch disabling mrproper in -devel rpms
- disable acerhk on x86_64 as it contains unsafe asm code
- fix mach64, ndiswrapper, ppscsi, rfswitch and viahss builds for linix-3.0
- update defconfigs
- update unionfs to 2.5.9.2
- disable aufs2 for now (broken)
- disable framebuffer oops fixes for now to verify if they are still needed
- rediff patches:
  3rd-3rdparty-merge.patch
  acpi-add-proc-event-regs.patch
  arm_fix_bad_udelay_usage.patch
  net-netfilter-psd.patch
  net-netfilter-psd-mdv.patch
  platform-x86-add-shuttle-wmi-driver.patch
  x86-cpufreq-speedstep-dothan-3.patch
  x86-p4_clockmod-reasonable-default-for-scaling_min_freq.patch
- drop merged patch:
  net-usb-rndis_host-poll-status-channel-before-control-channel.patch
- drop obsolete patch:
  mv643xx_eth_csum_part2.patch
- update to 3.0-rc7-git2
  * drop merged patches:
    ata-ahci-Intel-Panther-Point-ids.patch
    ata-ata_piix-Intel-Panther-Point-ids.patch
    block-blkdev_get-should-access-bd_disk-only-after.patch
    block-export-blk_-get-put-_queue.patch
    fs-ext4-init-timer-earlier-to-avoid-a-kernel-panic-in-__save_error_info_CVE-2011-2493.patch
    fs-fat-fix-corrupt-inode-flags-when-remove-attr_sys-flag.patch
    fs-proc-restrict-access-to-proc-PID-io_CVE-2011-2495.patch
    gpu-drm-i915-add-a-no-lvds-quirk-for-the-asus-eeebox-pc-eb1007.patch
    gpu-drm-i915-Avoid-unmapping-pages-from-a-NULL-address-s.patch
    gpu-drm-i915-dp-Sanity-check-eDP-existence.patch
    gpu-drm-i915-Enable-GPU-semaphores-by-default.patch
    gpu-drm-i915-Fix-tiling-corruption-from-pipelined-fencin.patch
    gpu-drm-i915-Restore-missing-command-flush-before-interr.patch
    gpu-drm-radeon-kms-fix-for-radeon-on-systems-4gb-without.patch
    gpu-drm-radeon-kms-viewport-height-has-to-be-even.patch
    gpu-drm-Retry-i2c-transfer-of-EDID-block-after-failure.patch
    hwmon-coretemp-relax-target-temperature-range-check.patch
    kernel-taskstats-dont-allow-duplicate-entries-in-listener-mode_CVE-2011-2484.patch
    mm-ksm-fix-race-between-ksmd-and-exiting-task-CVE-2011-2183.patch
    net-bluetooth-l2cap-and-rfcomm-fix-1-byte-infoleak-to-userspace_CVE-2011-2492.patch
    net-bluetooth-Prevent-buffer-overflow-in-l2cap-config-request_CVE-2011-2497.patch
    net-ipv4-check-for-mistakenly-passed-in-non-ipv4-address.patch
    net-ipv4-inet_diag-fix-inet_diag_bc_audit_CVE-2011-2213.patch
    net-netfilter-ipset-6.2.patch
    net-netfilter-ipset-6.4.patch
    net-r8169-add-a-new-chip-for-RTL8105.patch
    net-r8169-add-a-new-chip-for-RTL8168DP.patch
    net-r8169-Be-verbose-when-unable-to-load-fw.patch
    net-r8169-support-RTL8168E-RTL8111E.patch
    net-r8169-support-the-new-chips-for-RTL8105E.patch
    net-wireless-ath9k-Fix-a-locking-related-issue.patch
    net-wireless-ath9k-fix-two-more-bugs-in-tx-power.patch
    net-wireless-ath9k-reset-chip-on-baseband-hang.patch
    net-wireless-ath9k-set-40-mhz-rate-only-if-hw-is-configured-in-ht40.patch
    net-wireless-nl80211-fix-check-for-valid-ssid-size-in-scan-operations_CVE-2011-2517.patch
    net-wireless-nl80211-fix-overflow-in-ssid_len_CVE-2011-2517.patch
    pci-intel-iommu-add-domain-check-in-domain_remove_one_dev_info.patch
    pci-intel-iommu-check-for-identity-mapping-candidate-using.patch
    pci-intel-iommu-dont-cache-iova-above-32bit.patch
    pci-intel-iommu-flush-unmaps-at-domain_exit.patch
    pci-intel-iommu-only-unlink-device-domains-from-iommu.patch
    pci-intel-iommu-remove-host-bridge-devices-from-identity.patch
    pci-intel-iommu-speed-up-processing-of-the-identity_mapping.patch
    pci-intel-iommu-use-coherent-dma-mask-when-requested.patch
    platform-x86-hp-wmi-add-rfkill-support-for-wireless-query-0x1b.patch
    platform-x86-hp-wmi-allow-setting-input-and-output-buffer-sizes-s.patch
    platform-x86-hp-wmi-check-query-return-value-in-hp_wmi_perform_qu.patch
    platform-x86-hp-wmi-clear-rfkill-device-pointers-when-appropriate.patch
    platform-x86-hp-wmi-make-rfkill-initialization-failure-non-fatal.patch
    platform-x86-hp-wmi-remove-a-variable-that-is-never-read.patch
    platform-x86-hp-wmi-split-rfkill-initialization-out-of-hp_wmi_bio.patch
    platform-x86-samsung-laptop-add-support-for-N230-model.patch
    platform-x86-samsung-laptop-make-dmi_check_cb-to-return-1-instead-of-0.patch
    platform-x86-samsung-laptop.patch
    platform-x86-samsung-laptop-Samsung-R410P-backlight-driver.patch
    revert-dell-laptop-Toggle-the-unsupported-hardware-killswitch.patch
    revert-usb-option-add-id-for-zte-mf-330.patch
    scsi-fix-oops-caused-by-queue-refcounting-failure.patch
    security-tomoyo-fix-oops-in-tomoyo_mount_acl.patch
    usb-cdc-acm-adding-second-acm-channel-support-for-nokia-e7.patch
    usb-core-tolerate-protocol-stall-during-hub-and-port.patch
    usb-option-add-alcatel-x200-to-sendsetup-blacklist.patch
    usb-option-add-blacklist-for-zte-k3765-z-19d2-2002.patch
    usb-option-add-prolink-ph300-modem-ids.patch
    usb-option-add-zoom-4597-modem-usb-ids.patch
    usb-serial-add-another-4n-galaxy.de-pid-to-ftdi_sio-driver.patch
    usb-storage-redo-incorrect-reads.patch
    usb-usbnet-cdc_ncm-add-missing-.reset_resume-hook.patch
    video-fix-use-after-free-by-vga16fb-on-rmmod.patch
    watchdog-iTCO_wdt-add-Intel-Panther-Point-support.patch
    x86-amd-iommu-fix-3-possible-endless-loops.patch
    x86-amd-iommu-fix-boot-crash-with-hidden-pci-devices.patch
    x86-amd-iommu-use-only-per-device-dma_ops.patch
    xen-irq-implement-bind_interdomain_evtchn_to_irqhandler-for-backend-drivers.patch
    xen-network-backend-driver.patch
    xen-off-by-one-errors-in-multicalls.c.patch

* Fri Jul 08 2011 tmb <tmb> 2.6.38.8-5.mga2
+ Revision: 120242
- rebuild for missing packages

* Thu Jul 07 2011 tmb <tmb> 2.6.38.8-4.mga2
+ Revision: 119919
- fix non-expanding xen-pvops macros
- net/ipv4: Check for mistakenly passed in non-IPv4 address
- Bluetooth: Prevent buffer overflow in l2cap config request (CVE-2011-2497)
- Bluetooth: l2cap and rfcomm: fix 1 byte infoleak to userspace (CVE-2011-2492)
- proc: restrict access to /proc/PID/io (CVE-2011-2495)
- ext4: init timer earlier to avoid a kernel panic in __save_error_info (CVE-2011-2493)
- nl80211: fix overflow in ssid_len (CVE-2011-2517)
- TOMOYO: Fix oops in tomoyo_mount_acl() (CVE-2011-2518)
- inet_diag: fix inet_diag_bc_audit() (CVE-2011-2213)
- taskstats: don't allow duplicate entries in listener mode (CVE-2011-2484)

* Tue Jun 14 2011 tmb <tmb> 2.6.38.8-2.mga2
+ Revision: 106310
- add mgaver to 'uname -r'
- ath9k: revert changes that crashes the kernel (mga #144, regression since 2.6.35)
- xen: fix off by one errors in multicalls.c
- video: Fix use-after-free by vga16fb on rmmod
- nl80211: fix check for valid SSID size in scan operations (CVE-2011-2517)
- fat: Fix corrupt inode flags when remove ATTR_SYS flag
- intel-iommu: Flush unmaps at domain_exit
- intel-iommu: Only unlink device domains from iommu
- intel-iommu: Check for identity mapping candidate using system dma mask
- intel-iommu: Speed up processing of the identity_mapping function
- intel-iommu: Dont cache iova above 32bit
- intel-iommu: Use coherent DMA mask when requested
- intel-iommu: Remove Host Bridge devices from identity mapping
- intel-iommu: Add domain check in domain_remove_one_dev_info
- x86/amd-iommu: Fix 3 possible endless loops
- x86/amd-iommu: Use only per-device dma_ops
- x86/amd-iommu: Fix boot crash with hidden PCI devices
- usb: core: Tolerate protocol stall during hub and port status read
- usb-storage: redo incorrect reads
- usbnet/cdc_ncm: add missing .reset_resume hook
- usb: cdc-acm: Adding second ACM channel support for Nokia E7 and C7
- usb: serial: add another 4N-GALAXY.DE PID to ftdi_sio driver
- option: add Zoom 4597 modem USB IDs
- option: add Alcatel X200 to sendsetup blacklist
- option: add Prolink PH300 modem IDs
- option: Add blacklist for ZTE K3765-Z
- Revert "USB: option: add ID for ZTE MF 330" as its a usb hub
- ath9k: fix two more bugs in tx power
- ath9k: Reset chip on baseband hang
- ath9k: set 40 Mhz rate only if hw is configured in ht40
- drm/i915: Add a no lvds quirk for the Asus EeeBox PC EB1007
- drm/radeon/kms: viewport height has to be even
- drm/radeon/kms: fix for radeon on systems >4GB without hardware iommu

* Tue Jun 07 2011 tmb <tmb> 2.6.38.8-1.mga2
+ Revision: 101625
- block: export blk_{get,put}_queue()
- block: blkdev_get() should access ->bd_disk only after success
- scsi:  Fix oops caused by queue refcounting failure
- hwmon: coretemp: Relax target temperature range check
- ksm: fix race between ksmd and exiting task (CVE-2011-2183)
- update to 2.6.38.8 (CVE-2011-1017)
- drop merged patches

* Sun May 22 2011 tmb <tmb> 2.6.38.7-1.mga1
+ Revision: 100106
- r8169: add a new chip for RTL8105
- r8169: add a new chip for RTL8168DP
- r8169: add support for RTL8168E/RTL8111E
- update to 2.6.38.7 final (CVE-2011-1770, CVE-2011-1776, CVE-2011-1927, CVE-2011-2496)
- drop merged stable-queue fixes

* Thu May 19 2011 tmb <tmb> 2.6.38.6-2.mga1
+ Revision: 99781
- watchdog: iTCO_wdt: TCO Watchdog patch for Intel Panther Point PCH
- more stable fixes
  * cifs: clean up various nits in unicode routines
  * cifs: fix cifsConvertToUCS() for the mapchars case
  * iwlegacy: fix IBSS mode crashes
- merge current stable queue:
  * ARM: zImage: make sure the stack is 64-bit aligned
  * ASoC: SSM2602: Fix 'Mic Boost2' control
  * ASoC: UDA134x: Remove POWER_OFF_ON_STANDBY define
  * block: rescan partitions on invalidated devices on -ENOMEDIA too
  * can: fix SJA1000 dlc for RTR packets
  * cdrom: always check_disk_change() on open
  * cifs: add fallback in is_path_accessible for old servers
  * cifs: Fix memory over bound bug in cifs_parse_mount_options
  * clocksource: Install completely before selecting
  * dccp: handle invalid feature options length (CVE-2011-1770)
  * drm/radeon/kms: fix extended lvds info parsing
  * ehea: Fix memory hotplug oops
  * ehea: fix wrongly reported speed and port
  * media: Fix cx88 remote control input
  * hydra: Fix regression caused during net_device_ops conversion
  * ipheth: Properly distinguish length and alignment in URBs and skbs
  * libata: fix oops when LPM is used with PMP
  * libertas: fix cmdpendingq locking
  * megaraid_sas: Sanity check user supplied length before passing it to
    dma_alloc_coherent()
  * mm: use alloc_bootmem_node_nopanic() on really needed path
  * ne-h8300: Fix regression caused during net_device_ops conversion
  * net: dev_close() should check IFF_UP
  * net: ip_expire() must revalidate route (CVE-2011-1927)
  * net: slip, fix ldisc->open retval
  * PCH_GbE : Fixed the issue of checksum judgment
  * PCH_GbE : Fixed the issue of collision detection
  * pch_gbe: support ML7223 IOH
  * PM: Fix warning in pm_restrict_gfp_mask() during SNAPSHOT_S2RAM ioctl
  * PM / Hibernate: Fix ioctl SNAPSHOT_S2RAM
  * PM / Hibernate: Make snapshot_release() restore GFP mask
  * rapidio: fix default routing initialization
  * Revert "mmc: fix a race between card-detect rescan and clock-gate work
    instances"
  * rtc-s3c: fixup wake support for rtc
  * scsi: Revert "[SCSI] Retrieve the Caching mode page"
  * Revert "x86, AMD: Fix APIC timer erratum 400 affecting K8 Rev.A-E
    processors"
  * slcan: fix ldisc->open retval
  * tick: Clear broadcast active bit when switching to oneshot
  * tmpfs: fix off-by-one in max_blocks checks
  * tmpfs: fix race between swapoff and writepage
  * tmpfs: fix race between umount and swapoff
  * tmpfs: fix race between umount and writepage
  * tmpfs: fix spurious ENOSPC when racing with unswap
  * media/v4l: Release module if subdev registration fails
  * vmxnet3: Consistently disable irqs when taking adapter->cmd_lock
  * vmxnet3: Fix inconsistent LRO state after initialization
  * x86, AMD: Fix ARAT feature setting again
  * x86, apic: Fix spurious error interrupts triggering on all non-boot APs
  * x86: Fix UV BAU for non-consecutive nasids
  * x86, mce, AMD: Fix leaving freed data in a list
  * zorro8390: Fix regression caused during net_device_ops conversion

  + rtp <rtp>
    - Revert to unionfs 2.5.8 until 2.5.9 problems are solved (cf bug #1326 and
      unionfs ml)

* Tue May 10 2011 tmb <tmb> 2.6.38.6-1.mga1
+ Revision: 97089
- merge current stable queue:
  cifs: change bleft in decode_unicode_ssetup back to signed type
  cifs: check for bytes_remaining going to zero in CIFS_SessSetup
  cifs: handle errors from coalesce_t2
  cifs: refactor mid finding loop in cifs_demultiplex_thread
  cifs: sanitize length checking in coalesce_t2
  drm/radeon/kms: add pci id to acer travelmate quirk for 5730
  drm/radeon/kms: fix gart setup on fusion parts (v2) backport
  drm/i915/dp: Be paranoid in case we disable a DP before it is attached
  drm/i915/lvds: Only act on lid notify when the device is on
  drm/i915: Release object along create user fb error path
  efi: Validate size of EFI GUID partition entries (CVE-2011-1776)
  hw_breakpoints, powerpc: Fix CONFIG_HAVE_HW_BREAKPOINT off-case in ptrace_set_debugreg()
  iwlwifi: add {ack, plpc}_check module parameters
  ptrace: Prepare to fix racy accesses on task breakpoints
  thinkpad-acpi: module autoloading for newer Lenovo ThinkPads
  vm: Don't lock guardpage if the stack is growing up
  vm: fix vm_pgoff wrap in upward expansion
  x86, hw_breakpoints: Fix racy access to ptrace breakpoints
- revert: "dell-laptop: Toggle the unsupported hardware killswitch"
  as it causes regressions on existing hw (reported by Colin Guthrie)
- drop Amd K8 erratum 400 fix (merged)
- update to 2.6.38.6
- clean /lib/modules tree on uninstall
- disable ACPI_PROCFS_POWER as its obsoleted by the sysfs interface

* Tue May 03 2011 tmb <tmb> 2.6.38.5-1.mga1
+ Revision: 94519
- update unionfs to 2.5.9
- update to 2.6.38.5 (CVE-2011-2479, CVE-2011-2498)

* Sat Apr 30 2011 tmb <tmb> 2.6.38.5-0.rc1.1.mga1
+ Revision: 93738
- raise default vmalloc area to 192MB (Anssi, #904)
- r8169: be verbose when unable to load firmware
- samsung-laptop: drop backlight type setting patch as its 2.6.39 specific
- r8169: add support for RTL8105E
- samsung-laptop: set backlight type and add support for N230, R410P
- x86, AMD: K8 Rev.A-E processors are subject to erratum 400
- enable DEBUG_RODATA and DEBUG_SET_MODULE_RONX
- update to 2.6.38.5-rc1
- hp-wmi: add support for rfkill on HP Mini 5102 (Anssi)

* Fri Apr 22 2011 tmb <tmb> 2.6.38.4-1.mga1
+ Revision: 89804
- enable radeon kernel modesetting
- add aliases for old ieee1394 modules to the new firewire stack
- add ide/ahci/raid ids for Intel Panther Point
- update ipset to 6.4 (includes ipv6 support)
- intel_ips: fix monitor thread to use TASK_INTERRUPTIBLE
- disable powersaving on rt2800 as it is broken (noted by rtp)
- update aufs to aufs2.1-38 stable branch
- update to 2.6.38.4 (CVE-2011-2496)

* Sat Apr 16 2011 tmb <tmb> 2.6.38.3-1.mga1
+ Revision: 86561
- drm/radeon/kms: fix suspend on rv530 asics
- drm/radeon/kms: pll tweaks for rv6xx
- vm: fix mlock() on stack guard page
- vm: fix vm_pgoff wrap in stack expansion
- update 'drm/i915: Fix tiling corruption from pipelined fencing'
- drm: Retry i2c transfer of EDID block after failure
- drm/i915/dp: Sanity check eDP existence
- drm/i915: Restore missing command flush before interrupt on BLT ring
- drm/i915: Avoid unmapping pages from a NULL address space
- drm/i915: Enable GPU semaphores by default
- update to 2.6.38.3 final (CVE-2011-2496)
- drop merged xen revert patch
- re-enable debug

* Tue Apr 12 2011 tmb <tmb> 2.6.38.3-0.rc1.1.mga1
+ Revision: 84037
- add missing virtual provides
- revert: 'x86-64, mm: Put early page table high' as it breaks xen
- rediff HP Compaq DC7900 alsa patch
- update to 2.6.38.3-rc1
- drop merged patches

* Mon Apr 11 2011 tmb <tmb> 2.6.38.2-4.mga1
+ Revision: 83133
- add xen netdev backend support
- compress patch tarball with xz
- ath9k: fix a chip wakeup related crash in ath9k_start
- add xen-pvops kernel
- spec cleanup

  + rtp <rtp>
    - import arm support. The kernel can build iop32x, kirkwood and versatile (qemu)
      kernels but build only kirkwood and versatile atm.

* Sat Apr 02 2011 tmb <tmb> 2.6.38.2-2.mga1
+ Revision: 79847
- add module_alias matching old dm-raid45
- ALSA: Fix yet another race in disconnection
- ALSA: hda - Fix SPDIF out regression on ALC889
- ALSA: vmalloc buffers should use normal mmap
- ath9k: Fix kernel panic in AR2427
- cciss: fix lost command issue
- crypto: aesni-intel - fix problem with packets that are not multiple of 64b
- eCryptfs: ecryptfs_keyring_auth_tok_for_sig() bug fix
- eCryptfs: Unlock page in write_begin error path
- mac80211: initialize sta->last_rx in sta_info_alloc
- myri10ge: fix rmmod crash
- PCI/ACPI: Report ASPM support to BIOS if not disabled from command line
- perf: Better fit max unprivileged mlock pages for tools needs
- scsi/ses: Avoid kernel panic when lun 0 is not mapped
- scsi/ses: show devices for enclosures with no page 7
- sound/oss/opl3: validate voice and channel indexes
- x86-64, mm: Put early page table high
- drop -devel provides from -source as dkms fails to build correctly with -source
- Relax si_code check in rt_sigqueueinfo and rt_tgsigqueueinfo
- Revert "x86: Cleanup highmap after brk is concluded",
  as it causes systems to freeze on resume
- restore framebuffer oops and deadlock fixes by Herton as
  they seem to work better than the Ubuntu one (mdv#62864)

* Mon Mar 28 2011 tmb <tmb> 2.6.38.2-1.mga1
+ Revision: 78347
- update to 2.6.38.2 (CVE-2011-0726)
- add kernel-netbook build (mga #313)

* Thu Mar 24 2011 tmb <tmb> 2.6.38.1-1.mga1
+ Revision: 76866
- drm/i915: Fix pipelined fencing (colin, fdo bug #34584)
- enable ath9k debugging
- ath9k: Fix a locking related issue
- update to 2.6.38.1

* Sun Mar 20 2011 tmb <tmb> 2.6.38-1.mga1
+ Revision: 74958
- add 70 fixes from upstream -stable queue
- rediff S2 to apply cleanly
- fix acerhk build with 2.6.38 series kernels
- update filelists
- fix ndiswrapper build with 2.6.38
- update aufs2 to 2.6.38-rc
- update defconfigs
- rediff 3rd-3rdparty-merge.patch
- rediff fs-aufs2.1-for-2.6.37.patch
- rediff platform-x86-add-shuttle-wmi-driver.patch
- rediff char-agp-intel-new-Q57-id.patch
- rediff acpi-video-add-blacklist-to-use-vendor-driver.patch
- rediff acpi-add-proc-event-regs.patch
- rediff x86-pci-toshiba-equium-a60-assign-busses.patch
- update unionfs to 2.5.8
- update samsung-laptop driver
- drop old samsung-backlight driver
- update plymouth framebuffer oops fix (from ubuntu)
- disable broken docomo patches
- update to 2.6.38
   * drop merged patches:
     block-fix-mis-synchronisation-in-blkdev_issue_zeroout.patch
     btrfs-deal-with-short-returns-from-copy_from_user.patch
     dm-crypt-scale-to-multiple-CPUs-v5-2.6.36.patch
     drm-i915-fix-calculation-of-backlight-value-in-combined-mode.patch
     fs-squashfs-add-XZ-compression-configuration-option.patch
     fs-squashfs-add-XZ-compression-support.patch
     fs-squashfs-fix-use-of-uninitialised-variable-in-zlib-and-xz-decompressors.patch
     idle-intel_idle-update-Sandy-Bridge-core-C-state-residency-targets.patch
     kbuild-do-not-remove-a.out-kvm.h-and-kvm_para.h-on-headers_install_all.patch
     kernel-sched-autogroup-Fix-reference-leak.patch
     kernel-sched-automated-per-session-task-groups-20101130.patch
     kernel-sched-fix-potential-access-to-freed-memory.patch
     kernel-sched-Fix-struct-autogroup-memory-leak.patch
     lib-decompressors-add-boot-time-XZ-support.patch
     lib-decompressors-add-XZ-decompressor-module.patch
     net-wireless-ath9k-fix-race-conditions-when-stop-device.patch
     net-wireless-rtl8187-avoid-redundant-write-to-register-FF72.patch
     net-wireless-rtl8187-consolidate-anaparam-on-off-write-sequences.patch
     net-wireless-rtl8187-do-not-do-per-packet-TX-AGC.patch
     net-wireless-rtl8187-don-t-set-RTL818X_CONFIG3_GNT_SELECT.patch
     net-wireless-rtl8187-fix-wrong-register-initialization-in-8187B.patch
     net-wireless-rtl8187-move-pll-reset-at-start-out-of-ANAPARAM-write.patch
     net-wireless-rtl8187-remove-redundant-initialization-of-ARFR.patch
     net-wireless-rtl8187-remove-setting-of-beacon-atim-regs-from-init.patch
     net-wireless-rtl8187-remove-uneeded-setting-of-anaparam-write.patch
     net-wireless-rtl8187-restore-anaparam-registers-after-reset.patch
     net-wireless-zd1201-add-id.patch
     net-wireless-zd1211rw-add-id.patch
     nfs-fix-compilation-warning.patch
     nfs-nfsroot-should-default-to-proto-udp.patch
     x86-support-XZ-compressed-kernel.patch

* Tue Mar 15 2011 tmb <tmb> 2.6.37.4-1.mga1
+ Revision: 71895
- block: fix mis-synchronisation in blkdev_issue_zeroout()
- btrfs: deal with short returns from copy_from_user
- drm/i915: Fix calculation of backlight value in combined mode
- nfs: nfsroot should default to: proto=udp
- nfs: fix compilation warning
- update to 2.6.37.4

* Tue Mar 08 2011 tmb <tmb> 2.6.37.3-1.mga1
+ Revision: 66712
- add Mageia framebuffer boot logo
- update to 2.6.37.3 (CVE-2011-1013, CVE-2011-1076)
  * drop merged patches:
    mm-prevent-concurrent-unmap_mapping_range-on-the-same-inode.patch
    net-ipv4-tcp-fix-inet_twsk_deschedule.patch
    usb-serial-usb_wwan-fix-tty-null-dereference.patch
    revert-bluetooth-enable-usb-autosuspend-by-default-on-btusb.patch
    staging-brcm80211-bugfix-for-softmac-crash-on-multi-cpu-configurations.patch
    staging-brcm80211-remove-assert-to-avoid-panic-since-2.6.37-kernel.patch

* Sat Feb 26 2011 tmb <tmb> 2.6.37.2-1.mga1
+ Revision: 60143
- fix aufs2 -devel includes
- add aufs2 support
- staging: brcm80211: remove assert to avoid panic since 2.6.37 kernel
- staging: brcm80211: bugfix for softmac crash on multi cpu configurations
- USB: serial/usb_wwan, fix tty NULL dereference
- Revert 'Bluetooth: Enable USB autosuspend by default on btusb'
- mm: prevent concurrent unmap_mapping_range() on the same inode
- tcp: fix inet_twsk_deschedule()
- ath9k: fix race conditions when stop device (#144)
- i586 server kernel and x86_64 kernels needs to be compressed with gzip
  so they work with xen (got broken during lzma -> xz update, noted by
  Guillaume Rousse on mdv kernel-discuss ml)
- update to 2.6.37.2
  * drop merged patch
    fs-xfs-fix-dquot-shaker-deadlock.patch

* Sat Feb 19 2011 tmb <tmb> 2.6.37.1-1.mga1
+ Revision: 54140
- xfs: fix dquot shaker deadlock
- drop merged patches:
  idle-intel_idle-open-broadcast-clock-event-to-fix-boot-hang.patch
  idle-intel_idle-fix-a-shutdown-regression.patch
- rediff patches:
  kernel-sched-automated-per-session-task-groups-20101130.patch
  kernel-sched-autogroup-Fix-reference-leak.patch
  kernel-sched-Fix-struct-autogroup-memory-leak.patch
- update to 2.6.37.1
- intel_idle: update Sandy Bridge core C-state residency targets
- intel_idle: open broadcast clock event to prevent boot hang
              due to local apic stalls
- intel_idle: fix a shutdown regression due to open broadcast fix

* Tue Jan 25 2011 tmb <tmb> 2.6.37-3.mga1
+ Revision: 38796
- drop obsoletes/provides for ancient mandriva releases
- Squashfs: Fix use of uninitialised variable in zlib & xz decompressors
- update defconfigs
- add xz support for kernel, initrd and squashfs
  (from upstream 2.6.38-rc1)
- drop lzma support (obsoleted by xz support)
- disable sparc and powerpc in buildscripts too
- unpack patches tarball
- convert 3rdparty tarballs to patches
- build only for i586 and x86_64 for now

* Sat Jan 08 2011 tmb <tmb> 2.6.37-2.mga1
+ Revision: 1280
- drop SOURCE5, not needed anymore
- imported package kernel
- Created package structure for kernel.

